@@ -16,18 +16,17 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-
-
 """This module contains utilities for building an AEA."""
-
-import itertools
+import ast
 import logging
 import logging.config
 import os
 import pprint
+import sys
 from collections import defaultdict
 from copy import copy, deepcopy
 from pathlib import Path
+from subprocess import check_call  # nosec
 from typing import Any, Collection, Dict, List, Optional, Set, Tuple, Type, Union, cast
 
 import jsonschema
@@ -63,6 +62,7 @@ from aea.configurations.constants import (
 )
 from aea.configurations.constants import (
     DEFAULT_SKILL,
+    DOTTED_PATH_MODULE_ELEMENT_SEPARATOR,
     FETCHAI,
     PROTOCOLS,
     SIGNING_PROTOCOL,
@@ -76,8 +76,14 @@ from aea.crypto.helpers import verify_or_create_private_keys
 from aea.crypto.ledger_apis import DEFAULT_CURRENCY_DENOMINATIONS
 from aea.crypto.wallet import Wallet
 from aea.decision_maker.base import DecisionMakerHandler
-from aea.exceptions import AEAException, AEAValidationError
-from aea.helpers.base import find_topological_order, load_env_file, load_module
+from aea.error_handler.base import AbstractErrorHandler
+from aea.exceptions import AEAException, AEAValidationError, enforce
+from aea.helpers.base import (
+    ensure_dir,
+    find_topological_order,
+    load_env_file,
+    load_module,
+)
 from aea.helpers.exception_policy import ExceptionPolicyEnum
 from aea.helpers.install_dependency import install_dependency
 from aea.helpers.logging import AgentLoggerAdapter, WithLogger, get_logger
@@ -297,7 +303,8 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
     DEFAULT_LOOP_MODE = "async"
     DEFAULT_RUNTIME_MODE = "threaded"
     DEFAULT_SEARCH_SERVICE_ADDRESS = _DEFAULT_SEARCH_SERVICE_ADDRESS
-
+    AEA_CLASS = AEA
+    BUILD_TIMEOUT = 120
     loader = ConfigLoader.from_configuration_type(PackageType.AGENT)
 
     # pylint: disable=attribute-defined-outside-init
@@ -358,6 +365,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         if not is_full_reset:
             return
         self._default_ledger: Optional[str] = None
+        self._build_entrypoint: Optional[str] = None
         self._currency_denominations: Dict[str, str] = {}
         self._default_connection: Optional[PublicId] = None
         self._context_namespace: Dict[str, Any] = {}
@@ -365,12 +373,14 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         self._execution_timeout: Optional[float] = None
         self._max_reactions: Optional[int] = None
         self._decision_maker_handler_class: Optional[Type[DecisionMakerHandler]] = None
+        self._error_handler_class: Optional[Type[AbstractErrorHandler]] = None
         self._skill_exception_policy: Optional[ExceptionPolicyEnum] = None
         self._connection_exception_policy: Optional[ExceptionPolicyEnum] = None
         self._default_routing: Dict[PublicId, PublicId] = {}
         self._loop_mode: Optional[str] = None
         self._runtime_mode: Optional[str] = None
         self._search_service_address: Optional[str] = None
+        self._storage_uri: Optional[str] = None
 
         self._package_dependency_manager = _DependenciesManager()
         if self._with_default_packages:
@@ -428,7 +438,9 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
 
         :return: self
         """
-        dotted_path, class_name = decision_maker_handler_dotted_path.split(":")
+        dotted_path, class_name = decision_maker_handler_dotted_path.split(
+            DOTTED_PATH_MODULE_ELEMENT_SEPARATOR
+        )
         module = load_module(dotted_path, file_path)
 
         try:
@@ -444,6 +456,35 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
 
         return self
 
+    def set_error_handler(
+        self, error_handler_dotted_path: str, file_path: Path
+    ) -> "AEABuilder":
+        """
+        Set error handler class.
+
+        :param error_handler_dotted_path: the dotted path to the error handler
+        :param file_path: the file path to the file which contains the error handler
+
+        :return: self
+        """
+        dotted_path, class_name = error_handler_dotted_path.split(
+            DOTTED_PATH_MODULE_ELEMENT_SEPARATOR
+        )
+        module = load_module(dotted_path, file_path)
+
+        try:
+            _class = getattr(module, class_name)
+            self._error_handler_class = _class
+        except Exception as e:  # pragma: nocover
+            self.logger.error(
+                "Could not locate error handler for dotted path '{}', class name '{}' and file path '{}'. Error message: {}".format(
+                    dotted_path, class_name, file_path, e
+                )
+            )
+            raise  # log and re-raise because we should not build an agent from an. invalid configuration
+
+        return self
+
     def set_skill_exception_policy(
         self, skill_exception_policy: Optional[ExceptionPolicyEnum]
     ) -> "AEABuilder":  # pragma: nocover
@@ -509,6 +550,18 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         self._runtime_mode = runtime_mode
         return self
 
+    def set_storage_uri(
+        self, storage_uri: Optional[str]
+    ) -> "AEABuilder":  # pragma: nocover
+        """
+        Set the storage uri.
+
+        :param storage uri:  storage uri
+        :return: self
+        """
+        self._storage_uri = storage_uri
+        return self
+
     def set_search_service_address(
         self, search_service_address: str
     ) -> "AEABuilder":  # pragma: nocover
@@ -659,6 +712,18 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         self._default_ledger = identifier
         return self
 
+    def set_build_entrypoint(
+        self, build_entrypoint: Optional[str]
+    ) -> "AEABuilder":  # pragma: nocover
+        """
+        Set build entrypoint.
+
+        :param build_entrypoint: path to the builder script.
+        :return: the AEABuilder
+        """
+        self._build_entrypoint = build_entrypoint
+        return self
+
     def set_currency_denominations(
         self, currency_denominations: Dict[str, str]
     ) -> "AEABuilder":  # pragma: nocover
@@ -691,6 +756,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         configuration = load_component_configuration(
             component_type, directory, skip_consistency_check
         )
+        self._set_component_build_directory(configuration)
         self._check_can_add(configuration)
         # update dependency graph
         self._package_dependency_manager.add_component(configuration)
@@ -698,6 +764,24 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
 
         return self
 
+    def _set_component_build_directory(
+        self, configuration: ComponentConfiguration
+    ) -> None:
+        """
+        Set component build directory, create if not presents.
+
+        :param configuration: component configuration
+
+        :return: None
+        """
+        configuration.build_directory = os.path.join(
+            self.AEA_CLASS.get_build_dir(),
+            configuration.component_type.value,
+            configuration.author,
+            configuration.name,
+        )
+        ensure_dir(configuration.build_directory)
+
     def add_component_instance(self, component: Component) -> "AEABuilder":
         """
         Add already initialized component object to resources or connections.
@@ -819,6 +903,75 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         self.remove_component(ComponentId(ComponentType.CONTRACT, public_id))
         return self
 
+    def call_all_build_entrypoints(self):
+        """Call all the build entrypoints."""
+        for config in self._package_dependency_manager._dependencies.values():  # type: ignore # pylint: disable=protected-access
+            self.run_build_for_component_configuration(config, logger=self.logger)
+
+        if self._build_entrypoint:
+            self.logger.info("Building AEA package...")
+            source_directory = "."
+            target_directory = os.path.abspath(self.AEA_CLASS.get_build_dir())
+            build_entrypoint = cast(str, self._build_entrypoint)
+            self._run_build_entrypoint(
+                build_entrypoint, source_directory, target_directory, logger=self.logger
+            )
+
+    @classmethod
+    def run_build_for_component_configuration(
+        cls, config: ComponentConfiguration, logger: Optional[logging.Logger] = None
+    ) -> None:
+        """Run a build entrypoint script for component configuration."""
+        if not config.build_entrypoint:
+            return
+
+        enforce(bool(config.build_directory), f"{config}.build_directory is not set!")
+
+        if not config.build_directory:  # pragma: nocover
+            return
+
+        if logger:
+            logger.info(f"Building package {config.component_id}...")
+
+        source_directory = cast(str, config.directory)
+        target_directory = os.path.abspath(config.build_directory)
+        build_entrypoint = cast(str, config.build_entrypoint)
+        cls._run_build_entrypoint(
+            build_entrypoint, source_directory, target_directory, logger=logger
+        )
+
+    @classmethod
+    def _run_build_entrypoint(
+        cls,
+        build_entrypoint: str,
+        source_directory: str,
+        target_directory: str,
+        logger: Optional[logging.Logger] = None,
+    ) -> None:
+        """
+        Run a build entrypoint script.
+
+        :param build_entrypoint: the path to the build script relative to directory.
+        :param directory: the directory root for the entrypoint path.
+        :param logger: logger
+
+        :return: None
+        """
+        cls._check_valid_entrypoint(build_entrypoint, source_directory)
+
+        command = [sys.executable, build_entrypoint, target_directory]
+        command_str = " ".join(command)
+        if logger:
+            logger.info(f"Running command '{command_str}'")
+        try:
+            check_call(
+                command, cwd=source_directory, timeout=cls.BUILD_TIMEOUT
+            )  # nosec
+        except Exception as e:
+            raise AEAException(
+                f"An error occurred while running command '{command_str}': {str(e)}"
+            ) from e
+
     def _build_identity_from_wallet(self, wallet: Wallet) -> Identity:
         """
         Get the identity associated to a wallet.
@@ -936,7 +1089,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             crypto_store=wallet.connection_cryptos,
         )
         connection_ids = self._process_connection_ids(connection_ids)
-        aea = AEA(
+        aea = self.AEA_CLASS(
             identity,
             wallet,
             resources,
@@ -944,6 +1097,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             period=self._get_agent_act_period(),
             execution_timeout=self._get_execution_timeout(),
             max_reactions=self._get_max_reactions(),
+            error_handler_class=self._get_error_handler_class(),
             decision_maker_handler_class=self._get_decision_maker_handler_class(),
             skill_exception_policy=self._get_skill_exception_policy(),
             connection_exception_policy=self._get_connection_exception_policy(),
@@ -954,6 +1108,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             runtime_mode=self._get_runtime_mode(),
             connection_ids=connection_ids,
             search_service_address=self._get_search_service_address(),
+            storage_uri=self._get_storage_uri(),
             **deepcopy(self._context_namespace),
         )
         self._load_and_add_components(
@@ -1002,6 +1157,14 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             else self.DEFAULT_MAX_REACTIONS
         )
 
+    def _get_error_handler_class(self,) -> Optional[Type]:
+        """
+        Return the error handler class.
+
+        :return: error handler class
+        """
+        return self._error_handler_class
+
     def _get_decision_maker_handler_class(
         self,
     ) -> Optional[Type[DecisionMakerHandler]]:
@@ -1086,6 +1249,14 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             else self.DEFAULT_RUNTIME_MODE
         )
 
+    def _get_storage_uri(self) -> Optional[str]:
+        """
+        Return the storage uri.
+
+        :return: the storage uri
+        """
+        return self._storage_uri
+
     def _get_search_service_address(self) -> str:
         """
         Return the search service address.
@@ -1208,6 +1379,35 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
                 )
             )
 
+    @staticmethod
+    def _check_valid_entrypoint(build_entrypoint: str, directory: str):
+        """
+        Check a configuration has a valid entrypoint.
+
+        :param build_entrypoint: the build entrypoint.
+        :param directory: the directory from where to start reading the script.
+        :return: None
+        """
+        enforce(
+            build_entrypoint is not None,
+            "Package has not a build entrypoint specified.",
+        )
+        build_entrypoint = cast(str, build_entrypoint)
+        script_path = Path(directory) / build_entrypoint
+        enforce(
+            script_path.exists(), f"File '{build_entrypoint}' does not exists.",
+        )
+        enforce(
+            script_path.is_file(), f"'{build_entrypoint}' is not a file.",
+        )
+        try:
+            ast.parse(script_path.read_text())
+        except SyntaxError as e:
+            message = f"{str(e)}: {e.text}"
+            raise AEAException(
+                f"The Python script at '{build_entrypoint}' has a syntax error: {message}"
+            ) from e
+
     def set_from_configuration(
         self,
         agent_configuration: AgentConfig,
@@ -1226,6 +1426,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         # set name and other configurations
         self.set_name(agent_configuration.name)
         self.set_default_ledger(agent_configuration.default_ledger)
+        self.set_build_entrypoint(agent_configuration.build_entrypoint)
         self.set_currency_denominations(agent_configuration.currency_denominations)
         self.set_default_connection(agent_configuration.default_connection)
         self.set_period(agent_configuration.period)
@@ -1235,6 +1436,10 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             dotted_path = agent_configuration.decision_maker_handler["dotted_path"]
             file_path = agent_configuration.decision_maker_handler["file_path"]
             self.set_decision_maker_handler(dotted_path, file_path)
+        if agent_configuration.error_handler != {}:
+            dotted_path = agent_configuration.error_handler["dotted_path"]
+            file_path = agent_configuration.error_handler["file_path"]
+            self.set_error_handler(dotted_path, file_path)
         if agent_configuration.skill_exception_policy is not None:
             self.set_skill_exception_policy(
                 ExceptionPolicyEnum(agent_configuration.skill_exception_policy)
@@ -1246,6 +1451,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         self.set_default_routing(agent_configuration.default_routing)
         self.set_loop_mode(agent_configuration.loop_mode)
         self.set_runtime_mode(agent_configuration.runtime_mode)
+        self.set_storage_uri(agent_configuration.storage_uri)
 
         # load private keys
         for (
@@ -1263,65 +1469,19 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
                 ledger_identifier, private_key_path, is_connection=True
             )
 
-        component_ids = itertools.chain(
-            [
-                ComponentId(ComponentType.PROTOCOL, p_id)
-                for p_id in agent_configuration.protocols
-            ],
-            [
-                ComponentId(ComponentType.CONTRACT, p_id)
-                for p_id in agent_configuration.contracts
-            ],
-        )
-        for component_id in component_ids:
-            component_path = self.find_component_directory_from_component_id(
-                aea_project_path, component_id
-            )
-            self.add_component(
-                component_id.component_type,
-                component_path,
-                skip_consistency_check=skip_consistency_check,
+        for component_type in [
+            ComponentType.PROTOCOL,
+            ComponentType.CONTRACT,
+            ComponentType.CONNECTION,
+            ComponentType.SKILL,
+        ]:
+            self._add_components_of_type(
+                component_type,
+                agent_configuration,
+                aea_project_path,
+                skip_consistency_check,
             )
 
-        connection_ids = [
-            ComponentId(ComponentType.CONNECTION, p_id)
-            for p_id in agent_configuration.connections
-        ]
-        if len(connection_ids) != 0:
-            connection_import_order = self._find_import_order(
-                connection_ids, aea_project_path, skip_consistency_check
-            )
-
-            for connection_id in connection_import_order:
-                component_path = self.find_component_directory_from_component_id(
-                    aea_project_path, connection_id
-                )
-                self.add_component(
-                    connection_id.component_type,
-                    component_path,
-                    skip_consistency_check=skip_consistency_check,
-                )
-
-        skill_ids = [
-            ComponentId(ComponentType.SKILL, p_id)
-            for p_id in agent_configuration.skills
-        ]
-
-        if len(skill_ids) == 0:
-            return
-
-        skill_import_order = self._find_import_order(
-            skill_ids, aea_project_path, skip_consistency_check
-        )
-        for skill_id in skill_import_order:
-            component_path = self.find_component_directory_from_component_id(
-                aea_project_path, skill_id
-            )
-            self.add_component(
-                skill_id.component_type,
-                component_path,
-                skip_consistency_check=skip_consistency_check,
-            )
         self._custom_component_configurations = (
             agent_configuration.component_configurations
         )
@@ -1496,7 +1656,6 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         It deep-copies the configuration, to avoid undesired side-effects.
 
         :param configuration: the configuration object.
-        :param custom_config: the configurations to apply.
         :return: the new configuration instance.
         """
         new_configuration = deepcopy(configuration)
@@ -1506,6 +1665,43 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         new_configuration.update(custom_config)
         return new_configuration
 
+    def _add_components_of_type(
+        self,
+        component_type: ComponentType,
+        agent_configuration: AgentConfig,
+        aea_project_path: Path,
+        skip_consistency_check: bool,
+    ):
+        """
+        Add components of a given type.
+
+        :param component_type: the type of components to add.
+        :param agent_configuration: the agent configuration from where to retrieve the components.
+        :param aea_project_path: path to the AEA project.
+        :param skip_consistency_check: if true, skip consistency checks.
+        :return: None
+        """
+        public_ids = getattr(agent_configuration, component_type.to_plural())
+        component_ids = [
+            ComponentId(component_type, public_id) for public_id in public_ids
+        ]
+        if component_type in {ComponentType.PROTOCOL, ComponentType.CONTRACT}:
+            # if protocols or contracts, import order doesn't matter.
+            import_order = component_ids
+        else:
+            import_order = self._find_import_order(
+                component_ids, aea_project_path, skip_consistency_check
+            )
+        for component_id in import_order:
+            component_path = self.find_component_directory_from_component_id(
+                aea_project_path, component_id
+            )
+            self.add_component(
+                component_id.component_type,
+                component_path,
+                skip_consistency_check=skip_consistency_check,
+            )
+
 
 def make_component_logger(
     configuration: ComponentConfiguration, agent_name: str,
