@@ -39,7 +39,7 @@ from aea.crypto.registries import crypto_registry
 @click.pass_context
 @check_aea_project
 def get_address(click_context, type_):
-    """Get the address associated with the private key."""
+    """Get the address associated with a private key of the agent."""
     ctx = cast(Context, click_context.obj)
     address = _try_get_address(ctx, type_)
     click.echo(address)
