@@ -16,7 +16,6 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-
 """This module contains definitions of agent components."""
 import importlib.util
 import logging
@@ -106,6 +105,11 @@ class Component(ABC, WithLogger):
             raise ValueError("Directory already set.")
         self._directory = path
 
+    @property
+    def build_directory(self) -> Optional[str]:
+        """Get build directory for the component."""
+        return self.configuration.build_directory
+
 
 def load_aea_package(configuration: ComponentConfiguration) -> None:
     """
