@@ -77,3 +77,5 @@ DEFAULT_GIT_REF = "master"
 IMPORT_TEMPLATE_1 = "from packages.{author}.{type}.{name}"
 IMPORT_TEMPLATE_2 = "import packages.{author}.{type}.{name}"
 DEFAULT_ENV_DOTFILE = ".env"
+DOTTED_PATH_MODULE_ELEMENT_SEPARATOR = ":"
+LIBPROTOC_VERSION = "libprotoc 3.11.4"
