@@ -23,6 +23,7 @@ import logging
 import os
 import sys
 from pathlib import Path
+from typing import Optional
 
 from aea.configurations.base import AgentConfig, PackageType
 from aea.configurations.constants import (
@@ -136,16 +137,17 @@ def create_private_key(ledger_id: str, private_key_file: str) -> None:
 
 
 def try_generate_testnet_wealth(
-    identifier: str, address: str, _sync: bool = True
+    identifier: str, address: str, url: Optional[str] = None, _sync: bool = True
 ) -> None:
     """
     Try generate wealth on a testnet.
 
     :param identifier: the identifier of the ledger
     :param address: the address to check for
+    :param url: the url
     :param _sync: whether to wait to sync or not; currently unused
     :return: None
     """
     faucet_api = make_faucet_api(identifier)
     if faucet_api is not None:
-        faucet_api.get_wealth(address)
+        faucet_api.get_wealth(address, url)
