@@ -25,9 +25,6 @@ from aea.common import Address
 from aea.configurations.constants import DEFAULT_LEDGER
 
 
-DEFAULT_ADDRESS_KEY = DEFAULT_LEDGER
-
-
 class Identity:
     """
     The identity holds the public elements identifying an agent.
@@ -43,7 +40,7 @@ class Identity:
         name: str,
         address: Optional[str] = None,
         addresses: Optional[Dict[str, Address]] = None,
-        default_address_key: str = DEFAULT_ADDRESS_KEY,
+        default_address_key: str = DEFAULT_LEDGER,
     ):
         """
         Instantiate the identity.
