@@ -58,7 +58,6 @@ class AgentRunAsyncTask:
 
     def create_run_loop(self) -> None:
         """Create run loop."""
-        pass
 
     def start(self) -> None:
         """Start task."""
@@ -585,7 +584,8 @@ class MultiAgentManager:
 
         if not os.path.isdir(self.working_dir):  # pragma: nocover
             raise ValueError(f"{self.working_dir} is not a directory!")
-        os.makedirs(self._keys_dir)
+        if not os.path.exists(self._keys_dir):
+            os.makedirs(self._keys_dir)
 
     def _build_agent_alias(
         self,
