@@ -16,9 +16,7 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-
 """This module contains the base classes for the skills."""
-
 import datetime
 import inspect
 import logging
@@ -52,6 +50,7 @@ from aea.exceptions import (
 )
 from aea.helpers.base import _get_aea_logger_name_prefix, load_module
 from aea.helpers.logging import AgentLoggerAdapter
+from aea.helpers.storage.generic_storage import Storage
 from aea.multiplexer import MultiplexerStatus, OutBox
 from aea.protocols.base import Message
 from aea.skills.tasks import TaskManager
@@ -181,6 +180,11 @@ class SkillContext:
         """Get outbox."""
         return self._get_agent_context().outbox
 
+    @property
+    def storage(self) -> Optional[Storage]:
+        """Get optional storage for agent."""
+        return self._get_agent_context().storage
+
     @property
     def message_in_queue(self) -> Queue:
         """Get message in queue."""
@@ -315,6 +319,9 @@ class SkillComponent(ABC):
 
         :return: None
         """
+        super_obj = super()
+        if hasattr(super_obj, "setup"):
+            super_obj.setup()  # type: ignore  # pylint: disable=no-member
 
     @abstractmethod
     def teardown(self) -> None:
@@ -323,6 +330,9 @@ class SkillComponent(ABC):
 
         :return: None
         """
+        super_obj = super()
+        if hasattr(super_obj, "teardown"):
+            super_obj.teardown()  # type: ignore  # pylint: disable=no-member
 
     @classmethod
     @abstractmethod
@@ -567,11 +577,41 @@ class Handler(SkillComponent, ABC):
 class Model(SkillComponent, ABC):
     """This class implements an abstract model."""
 
+    def __init__(
+        self,
+        name: str,
+        skill_context: SkillContext,
+        configuration: Optional[SkillComponentConfiguration] = None,
+        keep_terminal_state_dialogues: Optional[bool] = None,
+        **kwargs,
+    ) -> None:
+        """
+        Initialize a model.
+
+        :param name: the name of the component.
+        :param configuration: the configuration for the component.
+        :param skill_context: the skill context.
+        :param keep_terminal_state_dialogues: specify do dialogues in terminal state should stay or not
+
+        :return: None
+        """
+        super().__init__(name, skill_context, configuration=configuration, **kwargs)
+
+        # used by dialogues if mixed with the Model
+        if keep_terminal_state_dialogues is not None:
+            self._keep_terminal_state_dialogues = keep_terminal_state_dialogues
+
     def setup(self) -> None:
         """Set the class up."""
+        super_obj = super()
+        if hasattr(super_obj, "setup"):
+            super_obj.setup()  # type: ignore  # pylint: disable=no-member
 
     def teardown(self) -> None:
         """Tear the class down."""
+        super_obj = super()
+        if hasattr(super_obj, "teardown"):
+            super_obj.teardown()  # type: ignore  # pylint: disable=no-member
 
     @classmethod
     def parse_module(  # pylint: disable=arguments-differ
