@@ -20,8 +20,10 @@
 """This module contains the implementation of the contract API request dispatcher."""
 import inspect
 import logging
-from typing import Callable, Optional, cast
+from collections.abc import Mapping
+from typing import Callable, Optional, Union, cast
 
+from aea.common import JSONLike
 from aea.contracts import Contract, contract_registry
 from aea.crypto.base import LedgerApi
 from aea.crypto.registries import Registry
@@ -130,7 +132,9 @@ class ContractApiRequestDispatcher(RequestDispatcher):
         ledger_api: LedgerApi,
         message: ContractApiMessage,
         dialogue: ContractApiDialogue,
-        response_builder: Callable[[bytes, ContractApiDialogue], ContractApiMessage],
+        response_builder: Callable[
+            [Union[bytes, JSONLike], ContractApiDialogue], ContractApiMessage
+        ],
     ) -> ContractApiMessage:
         """
         Dispatch a request to a user-defined contract method.
@@ -146,7 +150,7 @@ class ContractApiRequestDispatcher(RequestDispatcher):
             data = self._get_data(ledger_api, message, contract)
             response = response_builder(data, dialogue)
         except AEAException as e:
-            self.logger.error(str(e))
+            self.logger.error(f"Exception during contract request: {str(e)}")
             response = self.get_error_message(e, ledger_api, message, dialogue)
         except Exception as e:  # pylint: disable=broad-except  # pragma: nocover
             self.logger.error(
@@ -171,8 +175,12 @@ class ContractApiRequestDispatcher(RequestDispatcher):
         """
 
         def build_response(
-            data: bytes, dialogue: ContractApiDialogue
+            data: Union[bytes, JSONLike], dialogue: ContractApiDialogue
         ) -> ContractApiMessage:
+            if not isinstance(data, Mapping):
+                raise ValueError(
+                    f"Invalid state type, got={type(data)}, expected={JSONLike}."
+                )
             return cast(
                 ContractApiMessage,
                 dialogue.reply(
@@ -199,8 +207,12 @@ class ContractApiRequestDispatcher(RequestDispatcher):
         """
 
         def build_response(
-            tx: bytes, dialogue: ContractApiDialogue
+            tx: Union[bytes, JSONLike], dialogue: ContractApiDialogue
         ) -> ContractApiMessage:
+            if not isinstance(tx, Mapping):
+                raise ValueError(
+                    f"Invalid transaction type, got={type(tx)}, expected={JSONLike}."
+                )
             return cast(
                 ContractApiMessage,
                 dialogue.reply(
@@ -227,8 +239,12 @@ class ContractApiRequestDispatcher(RequestDispatcher):
         """
 
         def build_response(
-            tx: bytes, dialogue: ContractApiDialogue
+            tx: Union[bytes, JSONLike], dialogue: ContractApiDialogue
         ) -> ContractApiMessage:
+            if isinstance(tx, bytes):
+                raise ValueError(
+                    f"Invalid transaction type, got={type(tx)}, expected={JSONLike}."
+                )
             return cast(
                 ContractApiMessage,
                 dialogue.reply(
@@ -255,8 +271,12 @@ class ContractApiRequestDispatcher(RequestDispatcher):
         """
 
         def build_response(
-            rm: bytes, dialogue: ContractApiDialogue
+            rm: Union[bytes, JSONLike], dialogue: ContractApiDialogue
         ) -> ContractApiMessage:
+            if not isinstance(rm, bytes):
+                raise ValueError(
+                    f"Invalid message type, got={type(rm)}, expected=bytes."
+                )
             return cast(
                 ContractApiMessage,
                 dialogue.reply(
@@ -269,7 +289,7 @@ class ContractApiRequestDispatcher(RequestDispatcher):
 
     def _get_data(
         self, api: LedgerApi, message: ContractApiMessage, contract: Contract,
-    ) -> bytes:
+    ) -> Union[bytes, JSONLike]:
         """Get the data from the contract method, either from the stub or from the callable specified by the message."""
         # first, check if the custom handler for this type of request has been implemented.
         data = self._call_stub(api, message, contract)
@@ -283,7 +303,7 @@ class ContractApiRequestDispatcher(RequestDispatcher):
     @staticmethod
     def _call_stub(
         ledger_api: LedgerApi, message: ContractApiMessage, contract: Contract
-    ) -> Optional[bytes]:
+    ) -> Optional[Union[bytes, JSONLike]]:
         """Try to call stub methods associated to the contract API request performative."""
         try:
             method: Callable = getattr(contract, message.performative.value)
@@ -310,7 +330,7 @@ class ContractApiRequestDispatcher(RequestDispatcher):
     @staticmethod
     def _validate_and_call_callable(
         api: LedgerApi, message: ContractApiMessage, contract: Contract
-    ):
+    ) -> Union[bytes, JSONLike]:
         """
         Validate a Contract callable, given the performative.
 
