@@ -50,6 +50,7 @@ import (
 
 	aea "libp2p_node/aea"
 	"libp2p_node/dht/dhtnode"
+	monitoring "libp2p_node/dht/monitoring"
 	utils "libp2p_node/utils"
 )
 
@@ -67,10 +68,28 @@ func ignore(err error) {
 }
 
 const (
-	addressLookupTimeout                = 20 * time.Second
-	routingTableConnectionUpdateTimeout = 5 * time.Second
-	newStreamTimeout                    = 5 * time.Second
-	addressRegisterTimeout              = 3 * time.Second
+	addressLookupTimeout                 = 20 * time.Second
+	routingTableConnectionUpdateTimeout  = 5 * time.Second
+	newStreamTimeout                     = 5 * time.Second
+	addressRegisterTimeout               = 3 * time.Second
+	addressRegistrationDelay             = 0 * time.Second
+	monitoringNamespace                  = "acn"
+	metricDHTOpLatencyStore              = "dht_op_latency_store"
+	metricDHTOpLatencyLookup             = "dht_op_latency_lookup"
+	metricOpLatencyRegister              = "op_latency_register"
+	metricOpLatencyRoute                 = "op_latency_route"
+	metricOpRouteCount                   = "op_route_count"
+	metricOpRouteCountAll                = "op_route_count_all"
+	metricOpRouteCountSuccess            = "op_route_count_success"
+	metricServiceDelegateClientsCount    = "service_delegate_clients_count"
+	metricServiceDelegateClientsCountAll = "service_delegate_clients_count_all"
+	metricServiceRelayClientsCount       = "service_relay_clients_count"
+	metricServiceRelayClientsCountAll    = "service_relay_clients_count_all"
+)
+
+var (
+	//latencyBucketsMilliSeconds = []float64{1., 10., 20., 50., 100., 200., 500., 1000.}
+	latencyBucketsMicroSeconds = []float64{100., 500., 1e3, 1e4, 1e5, 5e5, 1e6}
 )
 
 // DHTPeer A full libp2p node for the Agents Communication Network.
@@ -78,12 +97,15 @@ const (
 // and can acts as a relay for `DHTClient`.
 // Optionally, it provides delegate service for tcp clients.
 type DHTPeer struct {
-	host         string
-	port         uint16
-	publicHost   string
-	publicPort   uint16
-	delegatePort uint16
-	enableRelay  bool
+	host           string
+	port           uint16
+	publicHost     string
+	publicPort     uint16
+	delegatePort   uint16
+	monitoringPort uint16
+	enableRelay    bool
+
+	registrationDelay time.Duration
 
 	key             crypto.PrivKey
 	publicKey       crypto.PubKey
@@ -100,8 +122,11 @@ type DHTPeer struct {
 	myAgentReady     func() bool
 	dhtAddresses     map[string]string
 	tcpAddresses     map[string]net.Conn
+	dhtAddressesLock sync.RWMutex
+	tcpAddressesLock sync.RWMutex
 	processEnvelope  func(*aea.Envelope) error
 
+	monitor    monitoring.MonitoringService
 	closing    chan struct{}
 	goroutines *sync.WaitGroup
 	logger     zerolog.Logger
@@ -110,17 +135,18 @@ type DHTPeer struct {
 // New creates a new DHTPeer
 func New(opts ...Option) (*DHTPeer, error) {
 	var err error
-	dhtPeer := &DHTPeer{}
+	dhtPeer := &DHTPeer{registrationDelay: addressRegistrationDelay}
 
 	dhtPeer.dhtAddresses = map[string]string{}
 	dhtPeer.tcpAddresses = map[string]net.Conn{}
+	dhtPeer.dhtAddressesLock = sync.RWMutex{}
+	dhtPeer.tcpAddressesLock = sync.RWMutex{}
 
 	for _, opt := range opts {
 		if err := opt(dhtPeer); err != nil {
 			return nil, err
 		}
 	}
-
 	dhtPeer.closing = make(chan struct{})
 	dhtPeer.goroutines = &sync.WaitGroup{}
 
@@ -203,6 +229,9 @@ func New(opts ...Option) (*DHTPeer, error) {
 
 	/* setup DHTPeer message handlers and services */
 
+	// setup monitoring
+	dhtPeer.setupMonitoring()
+
 	// relay service
 	if dhtPeer.enableRelay {
 		// Allow clients to register their agents addresses
@@ -234,13 +263,20 @@ func New(opts ...Option) (*DHTPeer, error) {
 	}
 
 	// if peer is joining an existing network, announce my agent address if set
-	if len(dhtPeer.bootstrapPeers) > 0 && dhtPeer.myAgentAddress != "" {
-		err := dhtPeer.registerAgentAddress(dhtPeer.myAgentAddress)
-		if err != nil {
-			dhtPeer.Close()
-			return nil, err
-		}
+	if len(dhtPeer.bootstrapPeers) > 0 {
 		dhtPeer.addressAnnounced = true
+		if dhtPeer.myAgentAddress != "" {
+			opLatencyRegister, _ := dhtPeer.monitor.GetHistogram(metricOpLatencyRegister)
+			timer := dhtPeer.monitor.Timer()
+			start := timer.NewTimer()
+			err := dhtPeer.registerAgentAddress(dhtPeer.myAgentAddress)
+			if err != nil {
+				dhtPeer.Close()
+				return nil, err
+			}
+			duration := timer.GetTimer(start)
+			opLatencyRegister.Observe(float64(duration.Microseconds()))
+		}
 	}
 
 	// aea addresses lookup
@@ -262,9 +298,75 @@ func New(opts ...Option) (*DHTPeer, error) {
 		ready.Wait()
 	}
 
+	// start monitoring
+	ready := &sync.WaitGroup{}
+	ready.Add(1)
+	go dhtPeer.startMonitoring(ready)
+	ready.Wait()
+
 	return dhtPeer, nil
 }
 
+func (dhtPeer *DHTPeer) setupMonitoring() {
+	if dhtPeer.monitoringPort != 0 {
+		dhtPeer.monitor = monitoring.NewPrometheusMonitoring(monitoringNamespace, dhtPeer.monitoringPort)
+	} else {
+		dhtPeer.monitor = monitoring.NewFileMonitoring(monitoringNamespace, false)
+	}
+
+	dhtPeer.addMonitoringMetrics()
+}
+
+func (dhtPeer *DHTPeer) startMonitoring(ready *sync.WaitGroup) {
+	_, _, linfo, _ := dhtPeer.getLoggers()
+	linfo().Msg("Starting monitoring service: " + dhtPeer.monitor.Info())
+	dhtPeer.monitor.Start()
+	ready.Done()
+}
+
+func (dhtPeer *DHTPeer) addMonitoringMetrics() {
+	buckets := latencyBucketsMicroSeconds
+	var err error
+	// acn primitives
+	_, err = dhtPeer.monitor.NewHistogram(metricDHTOpLatencyStore,
+		"Histogram for time to store a key in the DHT", buckets)
+	ignore(err)
+	_, err = dhtPeer.monitor.NewHistogram(metricDHTOpLatencyLookup,
+		"Histogram for time to find a key in the DHT", buckets)
+	ignore(err)
+	// acn main service
+	_, err = dhtPeer.monitor.NewHistogram(metricOpLatencyRegister,
+		"Histogram for end-to-end time to register an agent in the acn", buckets)
+	ignore(err)
+	_, err = dhtPeer.monitor.NewHistogram(metricOpLatencyRoute,
+		"Histogram for end-to-end time to route an envelope to its destination, excluding time to send envelope itself",
+		buckets)
+	ignore(err)
+	_, err = dhtPeer.monitor.NewGauge(metricOpRouteCount,
+		"Number of ongoing envelope routing requests")
+	ignore(err)
+	_, err = dhtPeer.monitor.NewCounter(metricOpRouteCountAll,
+		"Total number envelope routing requests, successful or not")
+	ignore(err)
+	_, err = dhtPeer.monitor.NewCounter(metricOpRouteCountSuccess,
+		"Total number envelope routed successfully")
+	ignore(err)
+	// acn delegate service
+	_, err = dhtPeer.monitor.NewGauge(metricServiceDelegateClientsCount,
+		"Number of active delagate connections")
+	ignore(err)
+	_, err = dhtPeer.monitor.NewCounter(metricServiceDelegateClientsCountAll,
+		"Number of all delagate clients, connected or disconnected")
+	ignore(err)
+	// acn relay service
+	_, err = dhtPeer.monitor.NewGauge(metricServiceRelayClientsCount,
+		"Number of active relay clients")
+	ignore(err)
+	_, err = dhtPeer.monitor.NewCounter(metricServiceRelayClientsCountAll,
+		"Total number of all relayed clients, connected or disconnected")
+	ignore(err)
+}
+
 func (dhtPeer *DHTPeer) setupLogger() {
 	fields := map[string]string{
 		"package": "DHTPeer",
@@ -289,6 +391,11 @@ func (dhtPeer *DHTPeer) getLoggers() (func(error) *zerolog.Event, func() *zerolo
 	return lerror, lwarn, linfo, ldebug
 }
 
+// SetLogLevel set utils logger level
+func (dhtPeer *DHTPeer) SetLogLevel(lvl zerolog.Level) {
+	dhtPeer.logger = dhtPeer.logger.Level(lvl)
+}
+
 // Close stops the DHTPeer
 func (dhtPeer *DHTPeer) Close() []error {
 	var err error
@@ -375,15 +482,26 @@ func (dhtPeer *DHTPeer) handleDelegateService(ready *sync.WaitGroup) {
 
 func (dhtPeer *DHTPeer) handleNewDelegationConnection(conn net.Conn) {
 	defer dhtPeer.goroutines.Done()
+	defer conn.Close()
+
+	// to limit spamming
+	time.Sleep(dhtPeer.registrationDelay)
+
+	nbrConns, _ := dhtPeer.monitor.GetGauge(metricServiceDelegateClientsCount)
+	nbrClients, _ := dhtPeer.monitor.GetCounter(metricServiceDelegateClientsCountAll)
+	opLatencyRegister, _ := dhtPeer.monitor.GetHistogram(metricOpLatencyRegister)
+	timer := dhtPeer.monitor.Timer()
+	start := timer.NewTimer()
 
 	lerror, _, linfo, _ := dhtPeer.getLoggers()
 
-	linfo().Msgf("received a new connection from %s", conn.RemoteAddr().String())
+	//linfo().Msgf("received a new connection from %s", conn.RemoteAddr().String())
 
 	// read agent address
 	buf, err := utils.ReadBytesConn(conn)
 	if err != nil {
 		lerror(err).Msg("while receiving agent's Address")
+		nbrConns.Dec()
 		return
 	}
 
@@ -392,9 +510,11 @@ func (dhtPeer *DHTPeer) handleNewDelegationConnection(conn net.Conn) {
 		conn.RemoteAddr().String(), addr)
 
 	// Add connection to map
+	dhtPeer.tcpAddressesLock.Lock()
 	dhtPeer.tcpAddresses[addr] = conn
+	dhtPeer.tcpAddressesLock.Unlock()
 	if dhtPeer.addressAnnounced {
-		linfo().Msgf("announcing tcp client address %s...", addr)
+		//linfo().Msgf("announcing tcp client address %s...", addr)
 		err = dhtPeer.registerAgentAddress(addr)
 		if err != nil {
 			lerror(err).Msgf("while announcing tcp client address %s to the dht", addr)
@@ -405,16 +525,22 @@ func (dhtPeer *DHTPeer) handleNewDelegationConnection(conn net.Conn) {
 	err = utils.WriteBytesConn(conn, []byte("DONE"))
 	ignore(err)
 
+	duration := timer.GetTimer(start)
+	opLatencyRegister.Observe(float64(duration.Microseconds()))
+
+	nbrConns.Inc()
+	nbrClients.Inc()
+
 	for {
 		// read envelopes
 		envel, err := utils.ReadEnvelopeConn(conn)
 		if err != nil {
 			if err == io.EOF {
-				linfo().Msgf("connection closed by client: %s", err.Error())
-				linfo().Msg("      stoppig...")
+				linfo().Str("addr", addr).Msgf("connection closed by client: %s, stopping...", err.Error())
 			} else {
-				lerror(err).Msg("while reading envelope from client connection, aborting...")
+				lerror(err).Str("addr", addr).Msg("while reading envelope from client connection, aborting...")
 			}
+			nbrConns.Dec()
 			break
 		}
 
@@ -427,6 +553,11 @@ func (dhtPeer *DHTPeer) handleNewDelegationConnection(conn net.Conn) {
 		}()
 	}
 
+	// Remove connection from map
+	dhtPeer.tcpAddressesLock.Lock()
+	delete(dhtPeer.tcpAddresses, addr)
+	dhtPeer.tcpAddressesLock.Unlock()
+
 }
 
 // ProcessEnvelope register callback function
@@ -449,21 +580,35 @@ func (dhtPeer *DHTPeer) MultiAddr() string {
 func (dhtPeer *DHTPeer) RouteEnvelope(envel *aea.Envelope) error {
 	lerror, lwarn, linfo, _ := dhtPeer.getLoggers()
 
+	routeCount, _ := dhtPeer.monitor.GetGauge(metricOpRouteCount)
+	routeCountAll, _ := dhtPeer.monitor.GetCounter(metricOpRouteCountAll)
+	routeCountSuccess, _ := dhtPeer.monitor.GetCounter(metricOpRouteCountSuccess)
+	opLatencyRoute, _ := dhtPeer.monitor.GetHistogram(metricOpLatencyRoute)
+	timer := dhtPeer.monitor.Timer()
+
+	routeCount.Inc()
+	routeCountAll.Inc()
+	start := timer.NewTimer()
+
 	target := envel.To
 
 	if target == dhtPeer.myAgentAddress {
 		linfo().Str("op", "route").Str("addr", target).
 			Msg("route envelope destinated to my local agent...")
 		for dhtPeer.myAgentReady != nil && !dhtPeer.myAgentReady() {
-			linfo().Str("op", "route").Str("addr", target).
+			lwarn().Str("op", "route").Str("addr", target).
 				Msg("agent not ready yet, sleeping for some time ...")
 			time.Sleep(time.Duration(100) * time.Millisecond)
 		}
 		if dhtPeer.processEnvelope != nil {
+			duration := timer.GetTimer(start)
+			opLatencyRoute.Observe(float64(duration.Microseconds()))
 			err := dhtPeer.processEnvelope(envel)
+			routeCount.Dec()
 			if err != nil {
 				return err
 			}
+			routeCountSuccess.Inc()
 		} else {
 			lwarn().Str("op", "route").Str("addr", target).
 				Msgf("ProcessEnvelope not set, ignoring envelope %s", envel.String())
@@ -471,54 +616,69 @@ func (dhtPeer *DHTPeer) RouteEnvelope(envel *aea.Envelope) error {
 	} else if conn, exists := dhtPeer.tcpAddresses[target]; exists {
 		linfo().Str("op", "route").Str("addr", target).
 			Msgf("destination is a delegate client %s", conn.RemoteAddr().String())
+		routeCount.Dec()
+		routeCountSuccess.Inc()
+		duration := timer.GetTimer(start)
+		opLatencyRoute.Observe(float64(duration.Microseconds()))
 		return utils.WriteEnvelopeConn(conn, envel)
 	} else {
 		var peerID peer.ID
 		var err error
-		if sPeerID, exists := dhtPeer.dhtAddresses[target]; exists {
+		dhtPeer.dhtAddressesLock.RLock()
+		sPeerID, exists := dhtPeer.dhtAddresses[target]
+		dhtPeer.dhtAddressesLock.RUnlock()
+		if exists {
 			linfo().Str("op", "route").Str("addr", target).
 				Msgf("destination is a relay client %s", sPeerID)
 			peerID, err = peer.Decode(sPeerID)
 			if err != nil {
 				lerror(err).Str("op", "route").Str("addr", target).
 					Msgf("CRITICAL couldn't parse peer id from relay client id")
+				routeCount.Dec()
 				return err
 			}
 		} else {
 			linfo().Str("op", "route").Str("addr", target).
-				Msg("did NOT found destination address locally, looking for it in the DHT...")
+				Msg("did NOT find destination address locally, looking for it in the DHT...")
 			peerID, err = dhtPeer.lookupAddressDHT(target)
 			if err != nil {
 				lerror(err).Str("op", "route").Str("addr", target).
 					Msg("while looking up address on the DHT")
+				routeCount.Dec()
 				return err
 			}
 		}
 
-		linfo().Str("op", "route").Str("addr", target).
-			Msgf("got peer id '%s' for agent address", peerID.Pretty())
+		//linfo().Str("op", "route").Str("addr", target).
+		//	Msgf("got peer id '%s' for agent address", peerID.Pretty())
 
-		linfo().Str("op", "route").Str("addr", target).
-			Msgf("opening stream to target %s...", peerID.Pretty())
+		//linfo().Str("op", "route").Str("addr", target).
+		//	Msgf("opening stream to target %s...", peerID.Pretty())
 		ctx, cancel := context.WithTimeout(context.Background(), newStreamTimeout)
 		defer cancel()
 		stream, err := dhtPeer.routedHost.NewStream(ctx, peerID, dhtnode.AeaEnvelopeStream)
 		if err != nil {
 			lerror(err).Str("op", "route").Str("addr", target).
 				Msgf("timeout, couldn't open stream to target %s", peerID.Pretty())
+			routeCount.Dec()
 			return err
 		}
 
+		duration := timer.GetTimer(start)
+		opLatencyRoute.Observe(float64(duration.Microseconds()))
+
 		linfo().Str("op", "route").Str("addr", target).
-			Msg("sending envelope to target...")
+			Msgf("sending envelope to target peer %s...", peerID.Pretty())
 		err = utils.WriteEnvelope(envel, stream)
 		if err != nil {
 			errReset := stream.Reset()
 			ignore(errReset)
 		} else {
+			routeCountSuccess.Inc()
 			stream.Close()
 		}
 
+		routeCount.Dec()
 		return err
 	}
 
@@ -528,6 +688,10 @@ func (dhtPeer *DHTPeer) RouteEnvelope(envel *aea.Envelope) error {
 func (dhtPeer *DHTPeer) lookupAddressDHT(address string) (peer.ID, error) {
 	lerror, lwarn, linfo, _ := dhtPeer.getLoggers()
 	var err error
+
+	dhtLookupLatency, _ := dhtPeer.monitor.GetHistogram(metricDHTOpLatencyLookup)
+	timer := dhtPeer.monitor.Timer()
+
 	addressCID, err := utils.ComputeCID(address)
 	if err != nil {
 		return "", err
@@ -537,27 +701,29 @@ func (dhtPeer *DHTPeer) lookupAddressDHT(address string) (peer.ID, error) {
 		Msgf("Querying for providers for cid %s...", addressCID.String())
 	ctx, cancel := context.WithTimeout(context.Background(), addressLookupTimeout)
 	defer cancel()
-	var elapsed time.Duration
+	//var elapsed time.Duration
 	var provider peer.AddrInfo
 	var connected bool = false
 	var stream network.Stream
 
-	start := time.Now()
+	start := timer.NewTimer()
 
+	noProvider := false
 	for !connected {
 		providers := dhtPeer.dht.FindProvidersAsync(ctx, addressCID, 0)
 
 		for provider = range providers {
-			elapsed = time.Since(start)
+			duration := timer.GetTimer(start)
+			dhtLookupLatency.Observe(float64(duration.Microseconds()))
 
-			linfo().Str("op", "lookup").Str("addr", address).
-				Msgf("found provider %s after %s", provider, elapsed.String())
+			//linfo().Str("op", "lookup").Str("addr", address).
+			//	Msgf("found provider %s after %s", provider, elapsed.String())
 
 			// Add peer to host PeerStore - the provider should be the holder of the address
 			dhtPeer.routedHost.Peerstore().AddAddrs(provider.ID, provider.Addrs, peerstore.PermanentAddrTTL)
 
-			linfo().Str("op", "lookup").Str("addr", address).
-				Msgf("opening stream to the address provider %s...", provider)
+			//linfo().Str("op", "lookup").Str("addr", address).
+			//	Msgf("opening stream to the address provider %s...", provider)
 			ctxConnect := context.Background()
 			stream, err = dhtPeer.routedHost.NewStream(ctxConnect, provider.ID, dhtnode.AeaAddressStream)
 			if err == nil {
@@ -566,16 +732,17 @@ func (dhtPeer *DHTPeer) lookupAddressDHT(address string) (peer.ID, error) {
 			}
 
 			dhtPeer.routedHost.Peerstore().ClearAddrs(provider.ID)
-			lwarn().Str("op", "lookup").Str("addr", address).Msgf("couldn't open stream to address provider %s: %s", provider, err.Error())
-			lwarn().Str("op", "lookup").Str("addr", address).Msgf("looking up for other providers...")
+			lwarn().Str("op", "lookup").Str("addr", address).Msgf("couldn't open stream to address provider %s: %s, looking up for other providers...", provider, err.Error())
 		}
 
 		if provider.ID == "" {
 			msg := "didn't find any provider for address"
-			lwarn().Str("op", "lookup").Str("addr", address).Msg(msg)
+			if !noProvider {
+				noProvider = true
+				lwarn().Str("op", "lookup").Str("addr", address).Msgf("%s, retrying...", msg)
+			}
 			select {
 			default:
-				lwarn().Str("op", "lookup").Str("addr", address).Msg("retrying...")
 				time.Sleep(200 * time.Millisecond)
 			case <-ctx.Done():
 				err = errors.New(msg + " " + address + " within timeout")
@@ -588,7 +755,7 @@ func (dhtPeer *DHTPeer) lookupAddressDHT(address string) (peer.ID, error) {
 	}
 
 	linfo().Str("op", "lookup").Str("addr", address).
-		Msg("reading peer ID from provider...")
+		Msgf("reading peer ID from provider %s...", provider)
 
 	err = utils.WriteBytes(stream, []byte(address))
 	if err != nil {
@@ -612,7 +779,7 @@ func (dhtPeer *DHTPeer) lookupAddressDHT(address string) (peer.ID, error) {
 func (dhtPeer *DHTPeer) handleAeaEnvelopeStream(stream network.Stream) {
 	lerror, lwarn, linfo, _ := dhtPeer.getLoggers()
 
-	linfo().Msg("Got a new aea envelope stream")
+	//linfo().Msg("Got a new aea envelope stream")
 
 	envel, err := utils.ReadEnvelope(stream)
 	if err != nil {
@@ -646,7 +813,7 @@ func (dhtPeer *DHTPeer) handleAeaEnvelopeStream(stream network.Stream) {
 func (dhtPeer *DHTPeer) handleAeaAddressStream(stream network.Stream) {
 	lerror, _, linfo, _ := dhtPeer.getLoggers()
 
-	linfo().Msgf("Got a new aea address stream")
+	//linfo().Msgf("Got a new aea address stream")
 
 	reqAddress, err := utils.ReadString(stream)
 	if err != nil {
@@ -657,9 +824,15 @@ func (dhtPeer *DHTPeer) handleAeaAddressStream(stream network.Stream) {
 		return
 	}
 
-	linfo().Str("op", "resolve").Str("addr", reqAddress).
-		Msg("Received query for addr")
+	//linfo().Str("op", "resolve").Str("addr", reqAddress).
+	//	Msg("Received query for addr")
 	var sPeerID string
+	dhtPeer.dhtAddressesLock.RLock()
+	idRelay, existsRelay := dhtPeer.dhtAddresses[reqAddress]
+	dhtPeer.dhtAddressesLock.RUnlock()
+	dhtPeer.tcpAddressesLock.RLock()
+	_, existsDelegate := dhtPeer.tcpAddresses[reqAddress]
+	dhtPeer.tcpAddressesLock.RUnlock()
 
 	if reqAddress == dhtPeer.myAgentAddress {
 		peerID, err := peer.IDFromPublicKey(dhtPeer.publicKey)
@@ -669,11 +842,11 @@ func (dhtPeer *DHTPeer) handleAeaAddressStream(stream network.Stream) {
 			return
 		}
 		sPeerID = peerID.Pretty()
-	} else if id, exists := dhtPeer.dhtAddresses[reqAddress]; exists {
+	} else if existsRelay {
 		linfo().Str("op", "resolve").Str("addr", reqAddress).
 			Msg("found address in my relay clients map")
-		sPeerID = id
-	} else if _, exists := dhtPeer.tcpAddresses[reqAddress]; exists {
+		sPeerID = idRelay
+	} else if existsDelegate {
 		linfo().Str("op", "resolve").Str("addr", reqAddress).
 			Msgf("found address in my delegate clients map")
 		peerID, err := peer.IDFromPublicKey(dhtPeer.publicKey)
@@ -685,8 +858,8 @@ func (dhtPeer *DHTPeer) handleAeaAddressStream(stream network.Stream) {
 		sPeerID = peerID.Pretty()
 	} else {
 		// needed when a relay client queries for a peer ID
-		linfo().Str("op", "resolve").Str("addr", reqAddress).
-			Msg("did NOT found the address locally, looking for it in the DHT...")
+		//linfo().Str("op", "resolve").Str("addr", reqAddress).
+		//	Msg("did NOT found the address locally, looking for it in the DHT...")
 		peerID, err := dhtPeer.lookupAddressDHT(reqAddress)
 		if err == nil {
 			linfo().Str("op", "resolve").Str("addr", reqAddress).
@@ -709,12 +882,16 @@ func (dhtPeer *DHTPeer) handleAeaAddressStream(stream network.Stream) {
 }
 
 func (dhtPeer *DHTPeer) handleAeaNotifStream(stream network.Stream) {
-	lerror, _, linfo, ldebug := dhtPeer.getLoggers()
+	lerror, _, _, ldebug := dhtPeer.getLoggers()
 
-	linfo().Str("op", "notif").
-		Msgf("Got a new notif stream")
+	//linfo().Str("op", "notif").
+	//	Msgf("Got a new notif stream")
 
 	if !dhtPeer.addressAnnounced {
+		opLatencyRegister, _ := dhtPeer.monitor.GetHistogram(metricOpLatencyRegister)
+		timer := dhtPeer.monitor.Timer()
+		start := timer.NewTimer()
+
 		// workaround: to avoid getting `failed to find any peer in table`
 		//  when calling dht.Provide (happens occasionally)
 		ldebug().Msg("waiting for notifying peer to be added to dht routing table...")
@@ -741,6 +918,7 @@ func (dhtPeer *DHTPeer) handleAeaNotifStream(stream network.Stream) {
 			}
 		}
 		if dhtPeer.enableRelay {
+			dhtPeer.dhtAddressesLock.RLock()
 			for addr := range dhtPeer.dhtAddresses {
 				err := dhtPeer.registerAgentAddress(addr)
 				if err != nil {
@@ -749,9 +927,10 @@ func (dhtPeer *DHTPeer) handleAeaNotifStream(stream network.Stream) {
 						Msg("while announcing relay client address")
 				}
 			}
-
+			dhtPeer.dhtAddressesLock.RUnlock()
 		}
 		if dhtPeer.delegatePort != 0 {
+			dhtPeer.tcpAddressesLock.RLock()
 			for addr := range dhtPeer.tcpAddresses {
 				err := dhtPeer.registerAgentAddress(addr)
 				if err != nil {
@@ -760,8 +939,11 @@ func (dhtPeer *DHTPeer) handleAeaNotifStream(stream network.Stream) {
 						Msg("while announcing delegate client address")
 				}
 			}
+			dhtPeer.tcpAddressesLock.RUnlock()
 
 		}
+		duration := timer.GetTimer(start)
+		opLatencyRegister.Observe(float64(duration.Microseconds()))
 	}
 	dhtPeer.addressAnnounced = true
 }
@@ -769,8 +951,17 @@ func (dhtPeer *DHTPeer) handleAeaNotifStream(stream network.Stream) {
 func (dhtPeer *DHTPeer) handleAeaRegisterStream(stream network.Stream) {
 	lerror, _, linfo, _ := dhtPeer.getLoggers()
 
-	linfo().Str("op", "register").
-		Msg("Got a new aea register stream")
+	// to limit spamming
+	time.Sleep(dhtPeer.registrationDelay)
+
+	nbrClients, _ := dhtPeer.monitor.GetCounter(metricServiceRelayClientsCountAll)
+
+	opLatencyRegister, _ := dhtPeer.monitor.GetHistogram(metricOpLatencyRegister)
+	timer := dhtPeer.monitor.Timer()
+	start := timer.NewTimer()
+
+	//linfo().Str("op", "register").
+	//	Msg("Got a new aea register stream")
 
 	clientAddr, err := utils.ReadBytes(stream)
 	if err != nil {
@@ -796,10 +987,14 @@ func (dhtPeer *DHTPeer) handleAeaRegisterStream(stream network.Stream) {
 	err = utils.WriteBytes(stream, []byte("donePeerID"))
 	ignore(err)
 
-	linfo().Str("op", "register").
-		Str("addr", string(clientAddr)).
-		Msgf("Received address registration request for peer id %s", string(clientPeerID))
+	nbrClients.Inc()
+
+	//linfo().Str("op", "register").
+	//	Str("addr", string(clientAddr)).
+	//	Msgf("Received address registration request for peer id %s", string(clientPeerID))
+	dhtPeer.dhtAddressesLock.Lock()
 	dhtPeer.dhtAddresses[string(clientAddr)] = string(clientPeerID)
+	dhtPeer.dhtAddressesLock.Unlock()
 	if dhtPeer.addressAnnounced {
 		linfo().Str("op", "register").
 			Str("addr", string(clientAddr)).
@@ -814,11 +1009,17 @@ func (dhtPeer *DHTPeer) handleAeaRegisterStream(stream network.Stream) {
 			return
 		}
 	}
+
+	duration := timer.GetTimer(start)
+	opLatencyRegister.Observe(float64(duration.Microseconds()))
 }
 
 func (dhtPeer *DHTPeer) registerAgentAddress(addr string) error {
 	_, _, linfo, _ := dhtPeer.getLoggers()
 
+	dhtStoreLatency, _ := dhtPeer.monitor.GetHistogram(metricDHTOpLatencyStore)
+	timer := dhtPeer.monitor.Timer()
+
 	addressCID, err := utils.ComputeCID(addr)
 	if err != nil {
 		return err
@@ -831,8 +1032,11 @@ func (dhtPeer *DHTPeer) registerAgentAddress(addr string) error {
 	linfo().Str("op", "register").
 		Str("addr", addr).
 		Msgf("Announcing address to the dht with cid key %s", addressCID.String())
+	start := timer.NewTimer()
 	err = dhtPeer.dht.Provide(ctx, addressCID, true)
 	if err != context.DeadlineExceeded {
+		duration := timer.GetTimer(start)
+		dhtStoreLatency.Observe(float64(duration.Microseconds()))
 		return err
 	}
 	return nil
