@@ -28,6 +28,7 @@ from concurrent.futures._base import CancelledError as ConcurrentCancelledError
 from concurrent.futures.thread import ThreadPoolExecutor
 from contextlib import suppress
 from enum import Enum
+from pathlib import Path
 from typing import Callable, Dict, List, Optional, Set, Type, Union, cast
 from urllib import parse
 from uuid import uuid4
@@ -66,7 +67,7 @@ from packages.fetchai.protocols.oef_search.message import OefSearchMessage
 
 _default_logger = logging.getLogger("aea.packages.fetchai.connections.soef")
 
-PUBLIC_ID = PublicId.from_str("fetchai/soef:0.13.0")
+PUBLIC_ID = PublicId.from_str("fetchai/soef:0.14.0")
 
 NOT_SPECIFIED = object()
 
@@ -256,6 +257,8 @@ class SOEFChannel:
         self.oef_search_dialogues = OefSearchDialogues()
 
         self._token_storage_path = token_storage_path
+        if self._token_storage_path is not None:
+            Path(self._token_storage_path).touch()
         self.declared_name = uuid4().hex
         self._unique_page_address = None  # type: Optional[str]
         self.agent_location = None  # type: Optional[Location]
@@ -621,7 +624,7 @@ class SOEFChannel:
                     await self._ping_command()
                 except asyncio.CancelledError:  # pylint: disable=try-except-raise
                     raise
-                except Exception:  # pylint: disable=broad-except
+                except Exception:  # pylint: disable=broad-except  # pragma: nocover
                     self.logger.exception("Error on periodic ping command!")
                 await asyncio.sleep(period)
 
@@ -978,10 +981,10 @@ class SOEFChannel:
                 response = await asyncio.shield(task)
             finally:
                 response = await task
-                enforce(
-                    "<response><message>Goodbye!</message></response>" in response,
-                    "No Goodbye response.",
-                )
+                if (
+                    "<response><message>Goodbye!</message></response>" not in response
+                ):  # pragma: nocover
+                    self.logger.debug(f"No Goodbye response. Response={response}")
                 self.unique_page_address = None
 
     async def _stop_periodic_ping_task(self) -> None:
