@@ -22,11 +22,11 @@
 import json
 import logging
 import random
-from typing import Any, Dict, List, Optional, cast
+from typing import Dict, List, Optional, cast
 
 from vyper.utils import keccak256
 
-from aea.common import Address
+from aea.common import Address, JSONLike
 from aea.configurations.base import PublicId
 from aea.contracts.base import Contract
 from aea.crypto.base import LedgerApi
@@ -38,7 +38,7 @@ from aea.crypto.fetchai import FetchAIApi
 _default_logger = logging.getLogger("aea.packages.fetchai.contracts.erc1155.contract")
 MAX_UINT_256 = 2 ^ 256 - 1
 
-PUBLIC_ID = PublicId.from_str("fetchai/erc1155:0.12.0")
+PUBLIC_ID = PublicId.from_str("fetchai/erc1155:0.13.0")
 
 
 class ERC1155Contract(Contract):
@@ -86,7 +86,7 @@ class ERC1155Contract(Contract):
         token_ids: List[int],
         data: Optional[bytes] = b"",
         gas: int = 300000,
-    ) -> Dict[str, Any]:
+    ) -> JSONLike:
         """
         Get the transaction to create a batch of tokens.
 
@@ -110,7 +110,7 @@ class ERC1155Contract(Contract):
                     "nonce": nonce,
                 }
             )
-            tx = cls._try_estimate_gas(ledger_api, tx)
+            tx = ledger_api.update_with_gas_estimate(tx)
             return tx
         if ledger_api.identifier in [CosmosApi.identifier, FetchAIApi.identifier]:
             tokens = []
@@ -136,7 +136,7 @@ class ERC1155Contract(Contract):
         token_id: int,
         data: Optional[bytes] = b"",
         gas: int = 300000,
-    ) -> Dict[str, Any]:
+    ) -> JSONLike:
         """
         Get the transaction to create a single token.
 
@@ -160,7 +160,7 @@ class ERC1155Contract(Contract):
                     "nonce": nonce,
                 }
             )
-            tx = cls._try_estimate_gas(ledger_api, tx)
+            tx = ledger_api.update_with_gas_estimate(tx)
             return tx
         if ledger_api.identifier in [CosmosApi.identifier, FetchAIApi.identifier]:
             msg = {
@@ -188,7 +188,7 @@ class ERC1155Contract(Contract):
         mint_quantities: List[int],
         data: Optional[bytes] = b"",
         gas: int = 500000,
-    ) -> Dict[str, Any]:
+    ) -> JSONLike:
         """
         Get the transaction to mint a batch of tokens.
 
@@ -215,7 +215,7 @@ class ERC1155Contract(Contract):
                     "nonce": nonce,
                 }
             )
-            tx = cls._try_estimate_gas(ledger_api, tx)
+            tx = ledger_api.update_with_gas_estimate(tx)
             return tx
         if ledger_api.identifier in [CosmosApi.identifier, FetchAIApi.identifier]:
             tokens = []
@@ -282,7 +282,7 @@ class ERC1155Contract(Contract):
         mint_quantity: int,
         data: Optional[bytes] = b"",
         gas: int = 300000,
-    ) -> Dict[str, Any]:
+    ) -> JSONLike:
         """
         Get the transaction to mint a single token.
 
@@ -308,7 +308,7 @@ class ERC1155Contract(Contract):
                     "nonce": nonce,
                 }
             )
-            tx = cls._try_estimate_gas(ledger_api, tx)
+            tx = ledger_api.update_with_gas_estimate(tx)
             return tx
         if ledger_api.identifier in [CosmosApi.identifier, FetchAIApi.identifier]:
             msg = {
@@ -333,7 +333,7 @@ class ERC1155Contract(Contract):
         contract_address: Address,
         agent_address: Address,
         token_id: int,
-    ) -> Dict[str, Dict[int, int]]:
+    ) -> JSONLike:
         """
         Get the balance for a specific token id.
 
@@ -373,7 +373,7 @@ class ERC1155Contract(Contract):
         signature: str,
         data: Optional[bytes] = b"",
         gas: int = 2818111,
-    ) -> Dict[str, Any]:
+    ) -> JSONLike:
         """
         Get the transaction for a trustless trade between two agents for a single token.
 
@@ -414,7 +414,7 @@ class ERC1155Contract(Contract):
                     "nonce": nonce,
                 }
             )
-            tx = cls._try_estimate_gas(ledger_api, tx)
+            tx = ledger_api.update_with_gas_estimate(tx)
             return tx
         raise NotImplementedError
 
@@ -425,7 +425,7 @@ class ERC1155Contract(Contract):
         contract_address: Address,
         agent_address: Address,
         token_ids: List[int],
-    ) -> Dict[str, Dict[int, int]]:
+    ) -> JSONLike:
         """
         Get the balances for a batch of specific token ids.
 
@@ -475,7 +475,7 @@ class ERC1155Contract(Contract):
         signature: str,
         data: Optional[bytes] = b"",
         gas: int = 2818111,
-    ) -> str:
+    ) -> JSONLike:
         """
         Get the transaction for a trustless trade between two agents for a batch of tokens.
 
@@ -516,6 +516,7 @@ class ERC1155Contract(Contract):
                     "nonce": nonce,
                 }
             )
+            tx = ledger_api.update_with_gas_estimate(tx)
             return tx
         raise NotImplementedError
 
@@ -745,28 +746,6 @@ class ERC1155Contract(Contract):
             return {"trade_nonce": trade_nonce}
         raise NotImplementedError
 
-    @staticmethod
-    def _try_estimate_gas(ledger_api: LedgerApi, tx: Dict[str, Any]) -> Dict[str, Any]:
-        """
-        Attempts to update the transaction with a gas estimate.
-
-        :param ledger_api: the ledger API
-        :param tx: the transaction
-        :return: the transaction (potentially updated)
-        """
-        try:
-            # try estimate the gas and update the transaction dict
-            gas_estimate = ledger_api.api.eth.estimateGas(transaction=tx)
-            _default_logger.debug(
-                "[ERC1155Contract]: gas estimate: {}".format(gas_estimate)
-            )
-            tx["gas"] = gas_estimate
-        except Exception as e:  # pylint: disable=broad-except
-            _default_logger.debug(
-                "[ERC1155Contract]: Error when trying to estimate gas: {}".format(e)
-            )
-        return tx
-
     @staticmethod
     def get_last_code_id(ledger_api: LedgerApi) -> int:
         """
