@@ -40,6 +40,7 @@ class LedgerApiDialogue(Dialogue):
     INITIAL_PERFORMATIVES = frozenset(
         {
             LedgerApiMessage.Performative.GET_BALANCE,
+            LedgerApiMessage.Performative.GET_STATE,
             LedgerApiMessage.Performative.GET_RAW_TRANSACTION,
             LedgerApiMessage.Performative.SEND_SIGNED_TRANSACTION,
             LedgerApiMessage.Performative.GET_TRANSACTION_RECEIPT,
@@ -48,7 +49,9 @@ class LedgerApiDialogue(Dialogue):
     TERMINAL_PERFORMATIVES = frozenset(
         {
             LedgerApiMessage.Performative.BALANCE,
+            LedgerApiMessage.Performative.STATE,
             LedgerApiMessage.Performative.TRANSACTION_RECEIPT,
+            LedgerApiMessage.Performative.ERROR,
         }
     )
     VALID_REPLIES = {
@@ -63,6 +66,9 @@ class LedgerApiDialogue(Dialogue):
                 LedgerApiMessage.Performative.ERROR,
             }
         ),
+        LedgerApiMessage.Performative.GET_STATE: frozenset(
+            {LedgerApiMessage.Performative.STATE, LedgerApiMessage.Performative.ERROR}
+        ),
         LedgerApiMessage.Performative.GET_TRANSACTION_RECEIPT: frozenset(
             {
                 LedgerApiMessage.Performative.TRANSACTION_RECEIPT,
@@ -78,6 +84,7 @@ class LedgerApiDialogue(Dialogue):
                 LedgerApiMessage.Performative.ERROR,
             }
         ),
+        LedgerApiMessage.Performative.STATE: frozenset(),
         LedgerApiMessage.Performative.TRANSACTION_DIGEST: frozenset(
             {LedgerApiMessage.Performative.GET_TRANSACTION_RECEIPT}
         ),
@@ -124,6 +131,8 @@ class LedgerApiDialogues(Dialogues, ABC):
 
     END_STATES = frozenset({LedgerApiDialogue.EndState.SUCCESSFUL})
 
+    _keep_terminal_state_dialogues = False
+
     def __init__(
         self,
         self_address: Address,
