@@ -16,7 +16,6 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-
 """Conftest module for Pytest."""
 import difflib
 import inspect
@@ -74,7 +73,9 @@ from aea.test_tools.constants import DEFAULT_AUTHOR
 
 from packages.fetchai.connections.local.connection import LocalNode, OEFLocalConnection
 from packages.fetchai.connections.oef.connection import OEFConnection
+from packages.fetchai.connections.p2p_libp2p.check_dependencies import build_node
 from packages.fetchai.connections.p2p_libp2p.connection import (
+    LIBP2P_NODE_MODULE_NAME,
     MultiAddr,
     P2PLibp2pConnection,
 )
@@ -141,6 +142,8 @@ COSMOS_PRIVATE_KEY_FILE = PRIVATE_KEY_PATH_SCHEMA.format(COSMOS)
 ETHEREUM_PRIVATE_KEY_FILE = PRIVATE_KEY_PATH_SCHEMA.format(ETHEREUM)
 FETCHAI_PRIVATE_KEY_FILE = PRIVATE_KEY_PATH_SCHEMA.format(FETCHAI)
 
+ETHEREUM_PRIVATE_KEY_TWO_FILE = "ethereum_private_key_two.txt"
+
 DEFAULT_AMOUNT = 1000000000000000000000
 
 # private keys with value on testnet
@@ -150,6 +153,9 @@ COSMOS_PRIVATE_KEY_PATH = os.path.join(
 ETHEREUM_PRIVATE_KEY_PATH = os.path.join(
     ROOT_DIR, "tests", "data", ETHEREUM_PRIVATE_KEY_FILE
 )
+ETHEREUM_PRIVATE_KEY_TWO_PATH = os.path.join(
+    ROOT_DIR, "tests", "data", ETHEREUM_PRIVATE_KEY_TWO_FILE
+)
 FETCHAI_PRIVATE_KEY_PATH = os.path.join(
     ROOT_DIR, "tests", "data", FETCHAI_PRIVATE_KEY_FILE
 )
@@ -197,14 +203,10 @@ NON_GENESIS_CONFIG_TWO = {
     "public_uri": "127.0.0.1:9002",
     "ledger_id": "cosmos",
 }
-PUBLIC_DHT_P2P_MADDR_1 = "/dns4/agents-p2p-dht.sandbox.fetch-ai.com/tcp/9000/p2p/16Uiu2HAkw1ypeQYQbRFV5hKUxGRHocwU5ohmVmCnyJNg36tnPFdx"
-PUBLIC_DHT_P2P_MADDR_2 = "/dns4/agents-p2p-dht.sandbox.fetch-ai.com/tcp/9001/p2p/16Uiu2HAmVWnopQAqq4pniYLw44VRvYxBUoRHqjz1Hh2SoCyjbyRW"
-PUBLIC_DHT_DELEGATE_URI_1 = "agents-p2p-dht.sandbox.fetch-ai.com:11000"
-PUBLIC_DHT_DELEGATE_URI_2 = "agents-p2p-dht.sandbox.fetch-ai.com:11001"
-PUBLIC_DHT_P2P_MADDR_1_PROD = "/dns4/agents-p2p-dht.prod.fetch-ai.com/tcp/9000/p2p/16Uiu2HAkw1ypeQYQbRFV5hKUxGRHocwU5ohmVmCnyJNg36tnPFdx"
-PUBLIC_DHT_P2P_MADDR_2_PROD = "/dns4/agents-p2p-dht.prod.fetch-ai.com/tcp/9001/p2p/16Uiu2HAmVWnopQAqq4pniYLw44VRvYxBUoRHqjz1Hh2SoCyjbyRW"
-PUBLIC_DHT_DELEGATE_URI_1_PROD = "agents-p2p-dht.prod.fetch-ai.com:11000"
-PUBLIC_DHT_DELEGATE_URI_2_PROD = "agents-p2p-dht.prod.fetch-ai.com:11001"
+PUBLIC_DHT_P2P_MADDR_1 = "/dns4/acn.fetch.ai/tcp/9000/p2p/16Uiu2HAkw1ypeQYQbRFV5hKUxGRHocwU5ohmVmCnyJNg36tnPFdx"
+PUBLIC_DHT_P2P_MADDR_2 = "/dns4/acn.fetch.ai/tcp/9001/p2p/16Uiu2HAmVWnopQAqq4pniYLw44VRvYxBUoRHqjz1Hh2SoCyjbyRW"
+PUBLIC_DHT_DELEGATE_URI_1 = "acn.fetch.ai:11000"
+PUBLIC_DHT_DELEGATE_URI_2 = "acn.fetch.ai:11001"
 
 # testnets
 COSMOS_TESTNET_CONFIG = {"address": COSMOS_DEFAULT_ADDRESS}
@@ -218,7 +220,7 @@ FETCHAI_TESTNET_CONFIG = {"address": FETCHAI_DEFAULT_ADDRESS}
 # common public ids used in the tests
 UNKNOWN_PROTOCOL_PUBLIC_ID = PublicId("unknown_author", "unknown_protocol", "0.1.0")
 UNKNOWN_CONNECTION_PUBLIC_ID = PublicId("unknown_author", "unknown_connection", "0.1.0")
-MY_FIRST_AEA_PUBLIC_ID = PublicId.from_str("fetchai/my_first_aea:0.15.0")
+MY_FIRST_AEA_PUBLIC_ID = PublicId.from_str("fetchai/my_first_aea:0.16.0")
 
 DUMMY_SKILL_PATH = os.path.join(CUR_PATH, "data", "dummy_skill", SKILL_YAML)
 
@@ -250,6 +252,7 @@ protocol_config_files = [
     os.path.join(FETCHAI_PREF, "protocols", "signing", PROTOCOL_YAML),
     os.path.join(FETCHAI_PREF, "protocols", "state_update", PROTOCOL_YAML),
     os.path.join(FETCHAI_PREF, "protocols", "tac", PROTOCOL_YAML),
+    os.path.join(CUR_PATH, "data", "dummy_protocol", PROTOCOL_YAML),
 ]
 
 connection_config_files = [
@@ -619,6 +622,8 @@ def update_default_ethereum_ledger_api(ethereum_testnet_config):
     DEFAULT_LEDGER_CONFIGS[EthereumApi.identifier] = old_config
 
 
+@pytest.mark.integration
+@pytest.mark.ledger
 @pytest.fixture(scope="session")
 @action_for_platform("Linux", skip=False)
 def ganache(
@@ -779,6 +784,7 @@ def _make_libp2p_connection(
     delegate_host: str = "127.0.0.1",
     node_key_file: Optional[str] = None,
     agent_address: Optional[Address] = None,
+    build_directory: Optional[str] = None,
 ) -> P2PLibp2pConnection:
     log_file = "libp2p_node_{}.log".format(port)
     if os.path.exists(log_file):
@@ -787,6 +793,8 @@ def _make_libp2p_connection(
     if address is None:
         address = make_crypto(COSMOS).address
     identity = Identity("", address=address)
+    if not build_directory:
+        build_directory = os.getcwd()
     if relay and delegate:
         configuration = ConnectionConfig(
             node_key_file=node_key_file,
@@ -796,6 +804,7 @@ def _make_libp2p_connection(
             log_file=log_file,
             delegate_uri="{}:{}".format(delegate_host, delegate_port),
             connection_id=P2PLibp2pConnection.connection_id,
+            build_directory=build_directory,
         )
     elif relay and not delegate:
         configuration = ConnectionConfig(
@@ -805,6 +814,7 @@ def _make_libp2p_connection(
             entry_peers=entry_peers,
             log_file=log_file,
             connection_id=P2PLibp2pConnection.connection_id,
+            build_directory=build_directory,
         )
     else:
         configuration = ConnectionConfig(
@@ -813,8 +823,12 @@ def _make_libp2p_connection(
             entry_peers=entry_peers,
             log_file=log_file,
             connection_id=P2PLibp2pConnection.connection_id,
+            build_directory=build_directory,
         )
-    return P2PLibp2pConnection(configuration=configuration, identity=identity)
+    if not os.path.exists(os.path.join(build_directory, LIBP2P_NODE_MODULE_NAME)):
+        build_node(build_directory)
+    connection = P2PLibp2pConnection(configuration=configuration, identity=identity)
+    return connection
 
 
 def _make_libp2p_client_connection(
@@ -848,13 +862,16 @@ def libp2p_log_on_failure(fn: Callable) -> Callable:
     def wrapper(self, *args, **kwargs):
         try:
             fn(self, *args, **kwargs)
-        except Exception as e:
+        except Exception:
             for log_file in self.log_files:
                 print("libp2p log file ======================= {}".format(log_file))
-                with open(log_file, "r") as f:
-                    print(f.read())
+                try:
+                    with open(log_file, "r") as f:
+                        print(f.read())
+                except FileNotFoundError:
+                    pass
                 print("=======================================")
-            raise e
+            raise
 
     return wrapper
 
@@ -1039,6 +1056,88 @@ def erc1155_contract(ledger_api, ganache, ganache_addr, ganache_port):
     yield contract, contract_address
 
 
+@pytest.fixture()
+def erc20_contract(ledger_api, ganache, ganache_addr, ganache_port):
+    """Instantiate an ERC20 contract."""
+    directory = Path(ROOT_DIR, "packages", "fetchai", "contracts", "fet_erc20")
+    configuration = load_component_configuration(ComponentType.CONTRACT, directory)
+    configuration._directory = directory
+    configuration = cast(ContractConfig, configuration)
+
+    if str(configuration.public_id) not in contract_registry.specs:
+        # load contract into sys modules
+        Contract.from_config(configuration)
+
+    contract = contract_registry.make(str(configuration.public_id))
+
+    # get two accounts
+    account1 = EthereumCrypto(ETHEREUM_PRIVATE_KEY_PATH)
+    account2 = EthereumCrypto(ETHEREUM_PRIVATE_KEY_TWO_PATH)
+
+    tx = contract.get_deploy_transaction(
+        ledger_api=ledger_api,
+        deployer_address=account1.address,
+        gas=5000000,
+        name="FetERC20Mock",
+        symbol="MFET",
+        initialSupply=int(1e23),
+        decimals_=18,
+    )
+    gas = ledger_api.api.eth.estimateGas(transaction=tx)
+    tx["gas"] = gas
+    tx_signed = account1.sign_transaction(tx)
+    tx_receipt = ledger_api.send_signed_transaction(tx_signed)
+    receipt = ledger_api.get_transaction_receipt(tx_receipt)
+    contract_address = cast(Dict, receipt)["contractAddress"]
+
+    # Transfer some MFET to another default account
+    tx = contract.get_transfer_transaction(
+        ledger_api=ledger_api,
+        contract_address=contract_address,
+        from_address=account1.address,
+        gas=200000,
+        receiver=account2.address,
+        amount=int(1e20),
+    )
+    tx_signed = account1.sign_transaction(tx)
+    ledger_api.send_signed_transaction(tx_signed)
+
+    yield contract, contract_address
+
+
+@pytest.fixture()
+def oracle_contract(ledger_api, ganache, ganache_addr, ganache_port, erc20_contract):
+    """Instantiate a Fetch Oracle contract."""
+    directory = Path(ROOT_DIR, "packages", "fetchai", "contracts", "oracle")
+    configuration = load_component_configuration(ComponentType.CONTRACT, directory)
+    configuration._directory = directory
+    configuration = cast(ContractConfig, configuration)
+
+    if str(configuration.public_id) not in contract_registry.specs:
+        # load contract into sys modules
+        Contract.from_config(configuration)
+
+    contract = contract_registry.make(str(configuration.public_id))
+
+    _, erc20_address = erc20_contract
+
+    # deploy contract
+    crypto = EthereumCrypto(ETHEREUM_PRIVATE_KEY_PATH)
+
+    tx = contract.get_deploy_transaction(
+        ledger_api=ledger_api,
+        deployer_address=crypto.address,
+        gas=5000000,
+        ERC20Address=erc20_address,
+        initialFee=10000000000,
+    )
+    tx_signed = crypto.sign_transaction(tx)
+    tx_receipt = ledger_api.send_signed_transaction(tx_signed)
+    receipt = ledger_api.get_transaction_receipt(tx_receipt)
+    contract_address = cast(Dict, receipt)["contractAddress"]
+    yield contract, contract_address
+
+
 def env_path_separator() -> str:
     """
     Get the separator between path items in PATH variables, cross platform.
@@ -1066,3 +1165,12 @@ def random_string(length: int = 8) -> str:
 def make_uri(addr: str, port: int):
     """Make uri from address and port."""
     return f"{addr}:{port}"
+
+
+@pytest.mark.integration
+class UseGanache:
+    """Inherit from this class to use Ganache."""
+
+    @pytest.fixture(autouse=True)
+    def _start_ganache(self, ganache):
+        """Start a Ganache image."""
