@@ -44,7 +44,6 @@ class TProtocolNoCtDialogue(Dialogue):
         {
             TProtocolNoCtMessage.Performative.PERFORMATIVE_MT,
             TProtocolNoCtMessage.Performative.PERFORMATIVE_O,
-            TProtocolNoCtMessage.Performative.PERFORMATIVE_EMPTY_CONTENTS,
         }
     )
     VALID_REPLIES = {
@@ -122,6 +121,8 @@ class TProtocolNoCtDialogues(Dialogues, ABC):
         }
     )
 
+    _keep_terminal_state_dialogues = True
+
     def __init__(
         self,
         self_address: Address,
