@@ -54,12 +54,15 @@ Options:
   -v, --verbosity LVL           One of NOTSET, DEBUG, INFO, WARNING, ERROR,
                                 CRITICAL, OFF
 
-  -s, --skip-consistency-check  Skip consistency checks.
+  -s, --skip-consistency-check  Skip consistency checks of agent during command
+                                execution.
+
   --help                        Show this message and exit.
 
 Commands:
   add               Add a package to the agent.
   add-key           Add a private key to the wallet of the agent.
+  build             Build the agent and its components.
   config            Read or modify a configuration of the agent.
   create            Create a new agent.
   delete            Delete an agent.
@@ -85,6 +88,7 @@ Commands:
   push              Push a non-vendor package of the agent to the registry.
   register          Create a new registry account.
   remove            Remove a package from the agent.
+  remove-key        Remove a private key from the wallet of the agent.
   reset_password    Reset the password of the registry account.
   run               Run the agent.
   scaffold          Scaffold a package for the agent.
