@@ -16,21 +16,43 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-
 """This module contains the tests of the ethereum module."""
 
 import hashlib
 import logging
 import time
 from pathlib import Path
-from unittest.mock import MagicMock
+from unittest.mock import MagicMock, patch
 
-import eth_account
 import pytest
 
-from aea.crypto.ethereum import EthereumApi, EthereumCrypto, EthereumFaucetApi
+from aea.crypto.ethereum import (
+    AttributeDictTranslator,
+    EthereumApi,
+    EthereumCrypto,
+    EthereumFaucetApi,
+)
 
-from tests.conftest import ETHEREUM_PRIVATE_KEY_PATH, MAX_FLAKY_RERUNS, ROOT_DIR
+from tests.conftest import (
+    DEFAULT_GANACHE_CHAIN_ID,
+    ETHEREUM_PRIVATE_KEY_PATH,
+    MAX_FLAKY_RERUNS,
+    ROOT_DIR,
+)
+
+
+def test_attribute_dict_translator():
+    """Test the AttributeDictTranslator."""
+    di = {
+        "1": None,
+        "2": True,
+        "3": b"some",
+        "4": 0.1,
+        "5": [1, None, True, {}],
+        "6": {"hex": "0x01"},
+    }
+    res = AttributeDictTranslator.from_dict(di)
+    assert AttributeDictTranslator.to_dict(res) == di
 
 
 def test_creation():
@@ -104,12 +126,12 @@ def test_dump_positive():
     account.dump(MagicMock())
 
 
-def test_api_creation(ethereum_testnet_config, ganache):
+def test_api_creation(ethereum_testnet_config):
     """Test api instantiation."""
     assert EthereumApi(**ethereum_testnet_config), "Failed to initialise the api"
 
 
-def test_api_none(ethereum_testnet_config, ganache):
+def test_api_none(ethereum_testnet_config):
     """Test the "api" of the cryptoApi is none."""
     eth_api = EthereumApi(**ethereum_testnet_config)
     assert eth_api.api is not None, "The api property is None."
@@ -136,6 +158,19 @@ def test_get_balance(ethereum_testnet_config, ganache):
     assert balance > 0, "Existing account has no balance."
 
 
+@pytest.mark.flaky(reruns=MAX_FLAKY_RERUNS)
+@pytest.mark.integration
+@pytest.mark.ledger
+def test_get_state(ethereum_testnet_config, ganache):
+    """Test that get_state() with 'getBlock' function returns something containing the block number."""
+    ethereum_api = EthereumApi(**ethereum_testnet_config)
+    callable_name = "getBlock"
+    args = ("latest",)
+    block = ethereum_api.get_state(callable_name, *args)
+    assert block is not None, "response to getBlock is empty."
+    assert "number" in block, "response to getBlock() does not contain 'number'"
+
+
 @pytest.mark.flaky(reruns=MAX_FLAKY_RERUNS)
 @pytest.mark.integration
 @pytest.mark.ledger
@@ -155,7 +190,7 @@ def test_construct_sign_and_submit_transfer_transaction(
         amount=amount,
         tx_fee=30000,
         tx_nonce=tx_nonce,
-        chain_id=3,
+        chain_id=DEFAULT_GANACHE_CHAIN_ID,
     )
     assert (
         isinstance(transfer_transaction, dict) and len(transfer_transaction) == 7
@@ -163,8 +198,7 @@ def test_construct_sign_and_submit_transfer_transaction(
 
     signed_transaction = account.sign_transaction(transfer_transaction)
     assert (
-        isinstance(signed_transaction, eth_account.datastructures.SignedTransaction)
-        and len(signed_transaction) == 5
+        isinstance(signed_transaction, dict) and len(signed_transaction) == 5
     ), "Incorrect signed_transaction constructed."
 
     transaction_digest = ethereum_api.send_signed_transaction(signed_transaction)
@@ -199,9 +233,9 @@ def test_get_wealth_positive(caplog):
     with caplog.at_level(logging.DEBUG, logger="aea.crypto.ethereum._default_logger"):
         ethereum_faucet_api = EthereumFaucetApi()
         ec = EthereumCrypto()
-        ethereum_faucet_api.get_wealth(ec.address)
+        ethereum_faucet_api.get_wealth(ec.address, "some_url")
         assert (
-            "Response: " in caplog.text
+            "Invalid URL" in caplog.text
         ), f"Cannot find message in output: {caplog.text}"
 
 
@@ -247,3 +281,22 @@ def test_load_contract_interface():
     result = EthereumApi.load_contract_interface(path)
     assert "abi" in result
     assert "bytecode" in result
+
+
+@patch.object(EthereumApi, "_try_get_transaction_count", return_value=None)
+def test_ethereum_api_get_transfer_transaction(*args):
+    """Test EthereumApi.get_transfer_transaction."""
+    ethereum_api = EthereumApi()
+    assert ethereum_api.get_transfer_transaction(*[MagicMock()] * 7) is None
+
+
+def test_ethereum_api_get_deploy_transaction(*args):
+    """Test EthereumApi.get_deploy_transaction."""
+    ethereum_api = EthereumApi()
+    with patch.object(ethereum_api.api.eth, "getTransactionCount", return_value=None):
+        assert (
+            ethereum_api.get_deploy_transaction(
+                {"acc": "acc"}, "0x89205A3A3b2A69De6Dbf7f01ED13B2108B2c43e7"
+            )
+            is None
+        )
