@@ -78,7 +78,7 @@ class TestBuildSkill(AEATestCaseMany):
 
         simple_service_registration_aea = "simple_service_registration"
         self.fetch_agent(
-            "fetchai/simple_service_registration:0.17.0",
+            "fetchai/simple_service_registration:0.18.0",
             simple_service_registration_aea,
         )
         self.set_agent_context(simple_service_registration_aea)
@@ -96,7 +96,7 @@ class TestBuildSkill(AEATestCaseMany):
         self.set_config(setting_path, COSMOS)
 
         default_routing = {
-            "fetchai/oef_search:0.10.0": "fetchai/soef:0.13.0",
+            "fetchai/oef_search:0.11.0": "fetchai/soef:0.14.0",
         }
 
         # replace location
@@ -109,9 +109,9 @@ class TestBuildSkill(AEATestCaseMany):
         skill_name = "my_search"
         skill_id = AUTHOR + "/" + skill_name + ":" + DEFAULT_VERSION
         self.scaffold_item("skill", skill_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/soef:0.13.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.12.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/soef:0.14.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
         setting_path = "agent.default_routing"
         self.nested_set_config(setting_path, default_routing)
 
@@ -174,11 +174,10 @@ class TestBuildSkill(AEATestCaseMany):
 
         # run agents
         self.set_agent_context(simple_service_registration_aea)
+        self.run_cli_command("build", cwd=self._get_cwd())
         simple_service_registration_aea_process = self.run_agent()
 
         check_strings = (
-            "Downloading golang dependencies. This may take a while...",
-            "Finished downloading golang dependencies.",
             "Starting libp2p node...",
             "Connecting to libp2p node...",
             "Successfully connected to libp2p node!",
@@ -197,11 +196,10 @@ class TestBuildSkill(AEATestCaseMany):
         )
 
         self.set_agent_context(search_aea)
+        self.run_cli_command("build", cwd=self._get_cwd())
         search_aea_process = self.run_agent()
 
         check_strings = (
-            "Downloading golang dependencies. This may take a while...",
-            "Finished downloading golang dependencies.",
             "Starting libp2p node...",
             "Connecting to libp2p node...",
             "Successfully connected to libp2p node!",
