@@ -33,10 +33,10 @@ from aea.helpers.search.models import (
 )
 from aea.mail.base import Envelope, Message
 from aea.multiplexer import InBox, Multiplexer
-from aea.protocols.default.message import DefaultMessage
 from aea.protocols.dialogue.base import Dialogue as BaseDialogue
 
 from packages.fetchai.connections.local.connection import LocalNode, OEFLocalConnection
+from packages.fetchai.protocols.default.message import DefaultMessage
 from packages.fetchai.protocols.fipa.dialogues import FipaDialogue, FipaDialogues
 from packages.fetchai.protocols.fipa.message import FipaMessage
 from packages.fetchai.protocols.oef_search.dialogues import OefSearchDialogue
