@@ -53,8 +53,8 @@ class TestThermometerSkill(AEATestCaseMany):
         self.create_agents(thermometer_aea_name, thermometer_client_aea_name)
 
         default_routing = {
-            "fetchai/ledger_api:0.7.0": "fetchai/ledger:0.10.0",
-            "fetchai/oef_search:0.10.0": "fetchai/soef:0.13.0",
+            "fetchai/ledger_api:0.8.0": "fetchai/ledger:0.11.0",
+            "fetchai/oef_search:0.11.0": "fetchai/soef:0.14.0",
         }
 
         # generate random location
@@ -65,12 +65,12 @@ class TestThermometerSkill(AEATestCaseMany):
 
         # add packages for agent one and run it
         self.set_agent_context(thermometer_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/soef:0.13.0")
-        self.remove_item("connection", "fetchai/stub:0.12.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/ledger:0.10.0")
-        self.add_item("skill", "fetchai/thermometer:0.16.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/soef:0.14.0")
+        self.remove_item("connection", "fetchai/stub:0.13.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/ledger:0.11.0")
+        self.add_item("skill", "fetchai/thermometer:0.17.0")
         setting_path = (
             "vendor.fetchai.skills.thermometer.models.strategy.args.is_ledger_tx"
         )
@@ -98,12 +98,12 @@ class TestThermometerSkill(AEATestCaseMany):
 
         # add packages for agent two and run it
         self.set_agent_context(thermometer_client_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/soef:0.13.0")
-        self.remove_item("connection", "fetchai/stub:0.12.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/ledger:0.10.0")
-        self.add_item("skill", "fetchai/thermometer_client:0.16.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/soef:0.14.0")
+        self.remove_item("connection", "fetchai/stub:0.13.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/ledger:0.11.0")
+        self.add_item("skill", "fetchai/thermometer_client:0.17.0")
         setting_path = (
             "vendor.fetchai.skills.thermometer_client.models.strategy.args.is_ledger_tx"
         )
@@ -132,11 +132,10 @@ class TestThermometerSkill(AEATestCaseMany):
 
         # run AEAs
         self.set_agent_context(thermometer_aea_name)
+        self.run_cli_command("build", cwd=self._get_cwd())
         thermometer_aea_process = self.run_agent()
 
         check_strings = (
-            "Downloading golang dependencies. This may take a while...",
-            "Finished downloading golang dependencies.",
             "Starting libp2p node...",
             "Connecting to libp2p node...",
             "Successfully connected to libp2p node!",
@@ -150,11 +149,10 @@ class TestThermometerSkill(AEATestCaseMany):
         ), "Strings {} didn't appear in thermometer_aea output.".format(missing_strings)
 
         self.set_agent_context(thermometer_client_aea_name)
+        self.run_cli_command("build", cwd=self._get_cwd())
         thermometer_client_aea_process = self.run_agent()
 
         check_strings = (
-            "Downloading golang dependencies. This may take a while...",
-            "Finished downloading golang dependencies.",
             "Starting libp2p node...",
             "Connecting to libp2p node...",
             "Successfully connected to libp2p node!",
@@ -229,8 +227,8 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
         self.create_agents(thermometer_aea_name, thermometer_client_aea_name)
 
         default_routing = {
-            "fetchai/ledger_api:0.7.0": "fetchai/ledger:0.10.0",
-            "fetchai/oef_search:0.10.0": "fetchai/soef:0.13.0",
+            "fetchai/ledger_api:0.8.0": "fetchai/ledger:0.11.0",
+            "fetchai/oef_search:0.11.0": "fetchai/soef:0.14.0",
         }
 
         # generate random location
@@ -241,18 +239,18 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
 
         # add packages for agent one and run it
         self.set_agent_context(thermometer_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/soef:0.13.0")
-        self.remove_item("connection", "fetchai/stub:0.12.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/ledger:0.10.0")
-        self.add_item("skill", "fetchai/thermometer:0.16.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/soef:0.14.0")
+        self.remove_item("connection", "fetchai/stub:0.13.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/ledger:0.11.0")
+        self.add_item("skill", "fetchai/thermometer:0.17.0")
         setting_path = "agent.default_routing"
         self.nested_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/thermometer_aea:0.16.0", thermometer_aea_name
+            "fetchai/thermometer_aea:0.17.0", thermometer_aea_name
         )
         assert (
             diff == []
@@ -277,18 +275,18 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
 
         # add packages for agent two and run it
         self.set_agent_context(thermometer_client_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/soef:0.13.0")
-        self.remove_item("connection", "fetchai/stub:0.12.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/ledger:0.10.0")
-        self.add_item("skill", "fetchai/thermometer_client:0.16.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/soef:0.14.0")
+        self.remove_item("connection", "fetchai/stub:0.13.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/ledger:0.11.0")
+        self.add_item("skill", "fetchai/thermometer_client:0.17.0")
         setting_path = "agent.default_routing"
         self.nested_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/thermometer_client:0.17.0", thermometer_client_aea_name
+            "fetchai/thermometer_client:0.18.0", thermometer_client_aea_name
         )
         assert (
             diff == []
@@ -317,11 +315,10 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
 
         # run AEAs
         self.set_agent_context(thermometer_aea_name)
+        self.run_cli_command("build", cwd=self._get_cwd())
         thermometer_aea_process = self.run_agent()
 
         check_strings = (
-            "Downloading golang dependencies. This may take a while...",
-            "Finished downloading golang dependencies.",
             "Starting libp2p node...",
             "Connecting to libp2p node...",
             "Successfully connected to libp2p node!",
@@ -335,11 +332,10 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
         ), "Strings {} didn't appear in thermometer_aea output.".format(missing_strings)
 
         self.set_agent_context(thermometer_client_aea_name)
+        self.run_cli_command("build", cwd=self._get_cwd())
         thermometer_client_aea_process = self.run_agent()
 
         check_strings = (
-            "Downloading golang dependencies. This may take a while...",
-            "Finished downloading golang dependencies.",
             "Starting libp2p node...",
             "Connecting to libp2p node...",
             "Successfully connected to libp2p node!",
@@ -381,7 +377,7 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
             "received proposal=",
             "accepting the proposal from sender=",
             "received MATCH_ACCEPT_W_INFORM from sender=",
-            "requesting transfer transaction from ledger api...",
+            "requesting transfer transaction from ledger api for message=",
             "received raw transaction=",
             "proposing the transaction to the decision maker. Waiting for confirmation ...",
             "transaction signing was successful.",
