@@ -52,8 +52,8 @@ class TestWeatherSkills(AEATestCaseMany):
         self.create_agents(weather_station_aea_name, weather_client_aea_name)
 
         default_routing = {
-            "fetchai/ledger_api:0.7.0": "fetchai/ledger:0.10.0",
-            "fetchai/oef_search:0.10.0": "fetchai/soef:0.13.0",
+            "fetchai/ledger_api:0.8.0": "fetchai/ledger:0.11.0",
+            "fetchai/oef_search:0.11.0": "fetchai/soef:0.14.0",
         }
 
         # generate random location
@@ -64,13 +64,13 @@ class TestWeatherSkills(AEATestCaseMany):
 
         # prepare agent one (weather station)
         self.set_agent_context(weather_station_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/soef:0.13.0")
-        self.remove_item("connection", "fetchai/stub:0.12.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/ledger:0.10.0")
-        self.add_item("skill", "fetchai/weather_station:0.16.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.12.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/soef:0.14.0")
+        self.remove_item("connection", "fetchai/stub:0.13.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/ledger:0.11.0")
+        self.add_item("skill", "fetchai/weather_station:0.17.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
         dotted_path = (
             "vendor.fetchai.skills.weather_station.models.strategy.args.is_ledger_tx"
         )
@@ -100,13 +100,13 @@ class TestWeatherSkills(AEATestCaseMany):
 
         # prepare agent two (weather client)
         self.set_agent_context(weather_client_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/soef:0.13.0")
-        self.remove_item("connection", "fetchai/stub:0.12.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/ledger:0.10.0")
-        self.add_item("skill", "fetchai/weather_client:0.16.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.12.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/soef:0.14.0")
+        self.remove_item("connection", "fetchai/stub:0.13.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/ledger:0.11.0")
+        self.add_item("skill", "fetchai/weather_client:0.17.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
         dotted_path = (
             "vendor.fetchai.skills.weather_client.models.strategy.args.is_ledger_tx"
         )
@@ -135,11 +135,10 @@ class TestWeatherSkills(AEATestCaseMany):
 
         # run agents
         self.set_agent_context(weather_station_aea_name)
+        self.run_cli_command("build", cwd=self._get_cwd())
         weather_station_process = self.run_agent()
 
         check_strings = (
-            "Downloading golang dependencies. This may take a while...",
-            "Finished downloading golang dependencies.",
             "Starting libp2p node...",
             "Connecting to libp2p node...",
             "Successfully connected to libp2p node!",
@@ -153,11 +152,10 @@ class TestWeatherSkills(AEATestCaseMany):
         ), "Strings {} didn't appear in weather_station output.".format(missing_strings)
 
         self.set_agent_context(weather_client_aea_name)
+        self.run_cli_command("build", cwd=self._get_cwd())
         weather_client_process = self.run_agent()
 
         check_strings = (
-            "Downloading golang dependencies. This may take a while...",
-            "Finished downloading golang dependencies.",
             "Starting libp2p node...",
             "Connecting to libp2p node...",
             "Successfully connected to libp2p node!",
@@ -224,8 +222,8 @@ class TestWeatherSkillsFetchaiLedger(AEATestCaseMany):
         self.create_agents(weather_station_aea_name, weather_client_aea_name)
 
         default_routing = {
-            "fetchai/ledger_api:0.7.0": "fetchai/ledger:0.10.0",
-            "fetchai/oef_search:0.10.0": "fetchai/soef:0.13.0",
+            "fetchai/ledger_api:0.8.0": "fetchai/ledger:0.11.0",
+            "fetchai/oef_search:0.11.0": "fetchai/soef:0.14.0",
         }
 
         # generate random location
@@ -236,18 +234,18 @@ class TestWeatherSkillsFetchaiLedger(AEATestCaseMany):
 
         # add packages for agent one
         self.set_agent_context(weather_station_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/soef:0.13.0")
-        self.remove_item("connection", "fetchai/stub:0.12.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/ledger:0.10.0")
-        self.add_item("skill", "fetchai/weather_station:0.16.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/soef:0.14.0")
+        self.remove_item("connection", "fetchai/stub:0.13.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/ledger:0.11.0")
+        self.add_item("skill", "fetchai/weather_station:0.17.0")
         setting_path = "agent.default_routing"
         self.nested_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/weather_station:0.18.0", weather_station_aea_name
+            "fetchai/weather_station:0.19.0", weather_station_aea_name
         )
         assert (
             diff == []
@@ -274,18 +272,18 @@ class TestWeatherSkillsFetchaiLedger(AEATestCaseMany):
 
         # add packages for agent two
         self.set_agent_context(weather_client_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/soef:0.13.0")
-        self.remove_item("connection", "fetchai/stub:0.12.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.12.0")
-        self.add_item("connection", "fetchai/ledger:0.10.0")
-        self.add_item("skill", "fetchai/weather_client:0.16.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/soef:0.14.0")
+        self.remove_item("connection", "fetchai/stub:0.13.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
+        self.add_item("connection", "fetchai/ledger:0.11.0")
+        self.add_item("skill", "fetchai/weather_client:0.17.0")
         setting_path = "agent.default_routing"
         self.nested_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/weather_client:0.19.0", weather_client_aea_name
+            "fetchai/weather_client:0.20.0", weather_client_aea_name
         )
         assert (
             diff == []
@@ -313,11 +311,10 @@ class TestWeatherSkillsFetchaiLedger(AEATestCaseMany):
         self.nested_set_config(setting_path, location)
 
         self.set_agent_context(weather_station_aea_name)
+        self.run_cli_command("build", cwd=self._get_cwd())
         weather_station_process = self.run_agent()
 
         check_strings = (
-            "Downloading golang dependencies. This may take a while...",
-            "Finished downloading golang dependencies.",
             "Starting libp2p node...",
             "Connecting to libp2p node...",
             "Successfully connected to libp2p node!",
@@ -331,11 +328,10 @@ class TestWeatherSkillsFetchaiLedger(AEATestCaseMany):
         ), "Strings {} didn't appear in weather_station output.".format(missing_strings)
 
         self.set_agent_context(weather_client_aea_name)
+        self.run_cli_command("build", cwd=self._get_cwd())
         weather_client_process = self.run_agent()
 
         check_strings = (
-            "Downloading golang dependencies. This may take a while...",
-            "Finished downloading golang dependencies.",
             "Starting libp2p node...",
             "Connecting to libp2p node...",
             "Successfully connected to libp2p node!",
@@ -372,7 +368,7 @@ class TestWeatherSkillsFetchaiLedger(AEATestCaseMany):
             "received proposal=",
             "accepting the proposal from sender=",
             "received MATCH_ACCEPT_W_INFORM from sender=",
-            "requesting transfer transaction from ledger api...",
+            "requesting transfer transaction from ledger api for message=",
             "received raw transaction=",
             "proposing the transaction to the decision maker. Waiting for confirmation ...",
             "transaction signing was successful.",
